import logging

import djclick as click
from django.db.transaction import atomic

from aurora.core import registry
from aurora.core.models import CustomFieldType, FlexForm, OptionSet
from aurora.core.registry import field_registry
from aurora.registration.models import Registration

logger = logging.getLogger(__name__)


class NotRunningInTTYError(Exception):
    pass


INTRO = """<h1>Instruction and consent</h1>
<ul>
<li>Welcome, this page is meant to help UNICEF and humanitarian partners to register
 families with children in Ukraine who need humanitarian assistance inside Ukraine</li>
<li>This survey is voluntary and the information you provide will remain strictly confidential.</li>
<li>Participating in this survey does not mean that you are entitled to assistance.
UNICEF and humanitarian partners will analyze the data for possible eligibility.</li>
<li>Only information that is necessary to facilitate your family potential access to humanitarian
 assistance will be collected, used, and processed. The information collected may also
be used for related purposes, such as monitoring and reporting on the quality of services</li>
<li>If you do not give your consent to treat your personal data, we cannot register you on this page.
 To seek humanitarian assistance you may approach UNICEF and its partners</li>
<li>Your answers to our questions as well as your personal data and photo may be shared with
 other humanitarian organization for assessment or assistance delivery purposes in accordance
  with your will.</li>
<li>The information you provide may be transferred to a secure storage location</li>
<li>UNICEF will keep your personal data for a maximum of 5 years after last use.</li>
<li>For the purpose of this registration A household consists of a person or a group of
 related or unrelated persons, who (i) live together in the same dwelling unit, (ii) who share
 common living arrangements, (iii) who acknowledge the same person as the household head, (iv)and
 who eat together Please list only individuals who belong to your household as per this definition.
</li>
<li>If you are sharing a space with other household please invite them to register as separate
 households.</li>
</ul>
"""

ADMIN1 = """0;0;------
UA01;UA;Avtonomna Respublika Krym;Автономна Республіка Крим;Автономная Республика Крым
UA05;UA;Vinnytska;Вінницька;Винницкая
UA07;UA;Volynska;Волинська;Волынская
UA12;UA;Dnipropetrovska;Дніпропетровська;Днепропетровская
UA14;UA;Donetska;Донецька;Донецкая
UA18;UA;Zhytomyrska;Житомирська;Житомирская
UA21;UA;Zakarpatska;Закарпатська;Закарпатская
UA23;UA;Zaporizka;Запорізька;Запорожская
UA26;UA;Ivano-Frankivska;Івано-Франківська;Ивано-Франковская
UA32;UA;Kyivska;Київська;Киевская
UA35;UA;Kirovohradska;Кіровоградська;Кировоградская
UA44;UA;Luhanska;Луганська;Луганская
UA46;UA;Lvivska;Львівська;Львовская
UA48;UA;Mykolaivska;Миколаївська;Николаевская
UA51;UA;Odeska;Одеська;Одесская
UA53;UA;Poltavska;Полтавська;Полтавская
UA56;UA;Rivnenska;Рівненська;Ровенская
UA59;UA;Sumska;Сумська;Сумская
UA61;UA;Ternopilska;Тернопільська;Тернопольская
UA63;UA;Kharkivska;Харківська;Харьковская
UA65;UA;Khersonska;Херсонська;Херсонская
UA68;UA;Khmelnytska;Хмельницька;Хмельницкая
UA71;UA;Cherkaska;Черкаська;Черкасская
UA73;UA;Chernivetska;Чернівецька;Черновицкая
UA74;UA;Chernihivska;Чернігівська;Черниговская
UA80;UA;Kyivska;Київська;Киевская
UA85;UA;Sevastopilska;Севастопільська;Севастопольский
"""

ADMIN2 = """UA0102;UA01;Bakhchysaraiskyi;Бахчисарайський;Бахчисарайский
UA0104;UA01;Bilohirskyi;Білогірський;Белогорский
UA0106;UA01;Dzhankoiskyi;Джанкойський;Джанкойский
UA0108;UA01;Yevpatoriiskyi;Євпаторійський;Евпаторийский
UA0110;UA01;Kerchynskyi;Керченський;Керченский
UA0112;UA01;Kurmanskyi;Курманський;Курманский
UA0114;UA01;Perekopskyi;Перекопський;Перекопский
UA0116;UA01;Simferopolskyi;Сімферопольський;Симферопольский
UA0118;UA01;Feodosiiskyi;Феодосійський;Феодосийский
UA0120;UA01;Yaltynskyi;Ялтинський;Ялтинский
UA0502;UA05;Vinnytskyi;Вінницький;Винницкий
UA0504;UA05;Haisynskyi;Гайсинський;Гайсинский
UA0506;UA05;Zhmerynskyi;Жмеринський;Жмеринский
UA0508;UA05;Mohyliv-Podilskyi;Могилів-Подільський;Могилев-Подольский
UA0510;UA05;Tulchynskyi;Тульчинський;Тульчинский
UA0512;UA05;Khmilnytskyi;Хмільницький;Хмельницкий
UA0702;UA07;Volodymyr-Volynskyi;Володимир-Волинський;Владимир-Волынский
UA0704;UA07;Kamin-Kashyrskyi;Камінь-Каширський;Камень-Каширский
UA0706;UA07;Kovelskyi;Ковельський;Ковельский
UA0708;UA07;Lutskyi;Луцький;Луцкий
UA1202;UA12;Dniprovskyi;Дніпровський;Днипровский
UA1204;UA12;Kamianskyi;Кам’янський;Каменский
UA1206;UA12;Kryvorizkyi;Криворізький;Криворожский
UA1208;UA12;Nikopolskyi;Нікопольський;Никопольский
UA1210;UA12;Novomoskovskyi;Новомосковський;Новомосковский
UA1212;UA12;Pavlohradskyi;Павлоградський;Павлоградский
UA1214;UA12;Synelnykivskyi;Синельниківський;Синельниковский
UA1402;UA14;Bakhmutskyi;Бахмутський;Бахмутский
UA1404;UA14;Volnovaskyi;Волноваський;Волновахский
UA1406;UA14;Horlivskyi;Горлівський;Горловский
UA1408;UA14;Donetskyi;Донецький;Донецкий
UA1410;UA14;Kalmiuskyi;Кальміуський;Кальмиусский
UA1412;UA14;Kramatorskyi;Краматорський;Краматорский
UA1414;UA14;Mariupolskyi;Маріупольський;Мариупольский
UA1416;UA14;Pokrovskyi;Покровський;Покровский
UA1802;UA18;Berdychivskyi;Бердичівський;Бердичевский
UA1804;UA18;Zhytomyrskyi;Житомирський;Житомирский
UA1806;UA18;Korostenskyi;Коростенський;Коростенский
UA1808;UA18;Novohrad-Volynskyi;Новоград-Волинський;Новоград-Волынский
UA2102;UA21;Berehivskyi;Берегівський;Береговский
UA2104;UA21;Mukachivskyi;Мукачівський;Мукачевский
UA2106;UA21;Rakhivskyi;Рахівський;Раховский
UA2108;UA21;Tiachivskyi;Тячівський;Тячевский
UA2110;UA21;Uzhhorodskyi;Ужгородський;Ужгородский
UA2112;UA21;Khustskyi;Хустський;Хустский
UA2302;UA23;Berdianskyi;Бердянський;Бердянский
UA2304;UA23;Vasylivskyi;Василівський;Васильевский
UA2306;UA23;Zaporizkyi;Запорізький;Запорожский
UA2308;UA23;Melitopolskyi;Мелітопольський;Мелитопольский
UA2310;UA23;Polohivskyi;Пологівський;Пологовский
UA2602;UA26;Verkhovynskyi;Верховинський;Верховинский
UA2604;UA26;Ivano-Frankivskyi;Івано-Франківський;Ивано-Франковский
UA2606;UA26;Kaluskyi;Калуський;Калушский
UA2608;UA26;Kolomyiskyi;Коломийський;Коломыйский
UA2610;UA26;Kosivskyi;Косівський;Косовский
UA2612;UA26;Nadvirnianskyi;Надвірнянський;Надворнянский
UA3200;UA32;Chornobylska zona vidchuzhennia;Чорнобильська зона відчуження;Чернобыльская зона отчуждения
UA3202;UA32;Bilotserkivskyi;Білоцерківський;Белоцерковский
UA3204;UA32;Boryspilskyi;Бориспільський;Бориспольский
UA3206;UA32;Brovarskyi;Броварський;Броварский
UA3208;UA32;Buchanskyi;Бучанський;Бучанский
UA3210;UA32;Vyshhorodskyi;Вишгородський;Вышгородский
UA3212;UA32;Obukhivskyi;Обухівський;Обуховский
UA3214;UA32;Fastivskyi;Фастівський;Фастовский
UA3502;UA35;Holovanivskyi;Голованівський;Голованевский
UA3504;UA35;Kropyvnytskyi;Кропивницький;Кропивницкий
UA3506;UA35;Novoukrainskyi;Новоукраїнський;Новоукраинский
UA3508;UA35;Oleksandriiskyi;Олександрійський;Александрийский
UA4402;UA44;Alchevskyi;Алчевський;Алчевский
UA4404;UA44;Dovzhanskyi;Довжанський;Должанский
UA4406;UA44;Luhanskyi;Луганський;Луганский
UA4408;UA44;Rovenkivskyi;Ровеньківський;Ровеньковский
UA4410;UA44;Svativskyi;Сватівський;Сватовский
UA4412;UA44;Sievierodonetskyi;Сєвєродонецький;Северодонецкий
UA4414;UA44;Starobilskyi;Старобільський;Старобельский
UA4416;UA44;Shchastynskyi;Щастинський;Счастьинский
UA4602;UA46;Drohobytskyi;Дрогобицький;Дрогобычский
UA4604;UA46;Zolochivskyi;Золочівський;Золочевский
UA4606;UA46;Lvivskyi;Львівський;Львовский
UA4608;UA46;Sambirskyi;Самбірський;Самборский
UA4610;UA46;Stryiskyi;Стрийський;Стрыйский
UA4612;UA46;Chervonohradskyi;Червоноградський;Червоноградский
UA4614;UA46;Yavorivskyi;Яворівський;Яворовский
UA4802;UA48;Bashtanskyi;Баштанський;Баштанский
UA4804;UA48;Voznesenskyi;Вознесенський;Вознесенский
UA4806;UA48;Mykolaivskyi;Миколаївський;Николаевский
UA4808;UA48;Pervomaiskyi;Первомайський;Первомайский
UA5102;UA51;Berezivskyi;Березівський;Березовский
UA5104;UA51;Bilhorod-Dnistrovskyi;Білгород-Дністровський;Белгород-Днестровский
UA5106;UA51;Bolhradskyi;Болградський;Болградский
UA5108;UA51;Izmailskyi;Ізмаїльський;Измаильский
UA5110;UA51;Odeskyi;Одеський;Одесский
UA5112;UA51;Podilskyi;Подільський;Подольский
UA5114;UA51;Rozdilnianskyi;Роздільнянський;Раздельнянский
UA5302;UA53;Kremenchutskyi;Кременчуцький;Кременчугский
UA5304;UA53;Lubenskyi;Лубенський;Лубенский
UA5306;UA53;Myrhorodskyi;Миргородський;Миргородский
UA5308;UA53;Poltavskyi;Полтавський;Полтавский
UA5602;UA56;Varaskyi;Вараський;Варашский
UA5604;UA56;Dubenskyi;Дубенський;Дубенский
UA5606;UA56;Rivnenskyi;Рівненський;Ровенский
UA5608;UA56;Sarnenskyi;Сарненський;Сарненский
UA5902;UA59;Konotopskyi;Конотопський;Конотопский
UA5904;UA59;Okhtyrskyi;Охтирський;Ахтырский
UA5906;UA59;Romenskyi;Роменський;Роменский
UA5908;UA59;Sumskyi;Сумський;Сумский
UA5910;UA59;Shostkynskyi;Шосткинський;Шосткинский
UA6102;UA61;Kremenetskyi;Кременецький;Кременецкий
UA6104;UA61;Ternopilskyi;Тернопільський;Тернопольский
UA6106;UA61;Chortkivskyi;Чортківський;Чортковский
UA6302;UA63;Bohodukhivskyi;Богодухівський;Богодуховский
UA6304;UA63;Iziumskyi;Ізюмський;Изюмский
UA6306;UA63;Krasnohradskyi;Красноградський;Красноградский
UA6308;UA63;Kupianskyi;Куп'янський;Купянский
UA6310;UA63;Lozivskyi;Лозівський;Лозовский
UA6312;UA63;Kharkivskyi;Харківський;Харьковский
UA6314;UA63;Chuhuivskyi;Чугуївський;Чугуевский
UA6502;UA65;Beryslavskyi;Бериславський;Бериславский
UA6504;UA65;Henicheskyi;Генічеський;Генический
UA6506;UA65;Kakhovskyi;Каховський;Каховский
UA6508;UA65;Skadovskyi;Скадовський;Скадовский
UA6510;UA65;Khersonskyi;Херсонський;Херсонский
UA6802;UA68;Kamianets-Podilskyi;Кам'янець-Подільський;Каменец-Подольский
UA6804;UA68;Khmelnytskyi;Хмельницький;Хмельницкий
UA6806;UA68;Shepetivskyi;Шепетівський;Шепетовский
UA7102;UA71;Zvenyhorodskyi;Звенигородський;Звенигородский
UA7104;UA71;Zolotoniskyi;Золотоніський;Золотоношский
UA7106;UA71;Umanskyi;Уманський;Уманский
UA7108;UA71;Cherkaskyi;Черкаський;Черкасский
UA7302;UA73;Vyzhnytskyi;Вижницький;Вижницкий
UA7304;UA73;Dnistrovskyi;Дністровський;Днестровский
UA7306;UA73;Cnernivetskyi;Чернівецький;Черновицкий
UA7402;UA74;Koriukivskyi;Корюківський;Корюковский
UA7404;UA74;Nizhynskyi;Ніжинський;Нежинский
UA7406;UA74;Novhorod-Siverskyi;Новгород-Сіверський;Новгород-Северский
UA7408;UA74;Prylutskyi;Прилуцький;Прилукский
UA7410;UA74;Chernihivskyi;Чернігівський;Черниговский
UA8000;UA80;Kyivska;Київська;Киевский
UA8500;UA85;Sevastopilska;Севастопільська;Севастопольский"""

ADMIN3 = """UA0102000;UA0102;Sevastopilska;Севастопільська;Севастопольский
UA0102003;UA0102;Aromatnenska;Ароматненська;Ароматненский
UA0102005;UA0102;Bakhchysaraiska;Бахчисарайська;Бахчисарайский
UA0102009;UA0102;Verkhorichenska;Верхоріченська;Верхореченский
UA0102011;UA0102;Vilinska;Вілінська;Вилинский
UA0102013;UA0102;Holubynska;Голубинська;Голубинский
UA0102015;UA0102;Dolynnenska;Долинненська;Долинненский
UA0102017;UA0102;Zaliznychnenska;Залізничненська;Железнодорожненский
UA0102019;UA0102;Zelenivska;Зеленівська;Зеленовский
UA0102025;UA0102;Kashtanivska;Каштанівська;Каштановский
UA0102027;UA0102;Krasnomatska;Красномацька;Красномакский
UA0102029;UA0102;Kuibyshevska;Куйбишевська;Куйбышевский
UA0102033;UA0102;Pishchanivska;Піщанівська;Песчановский
UA0102035;UA0102;Plodivska;Плодівська;Плодовский
UA0102037;UA0102;Poshtivska;Поштівська;Почтовский
UA0102039;UA0102;Skalystivska;Скалистівська;Скалистовский
UA0102041;UA0102;Tabachnenska;Табачненська;Табачненский
UA0102045;UA0102;Tinystivska;Тінистівська;Тенистовский
UA0102047;UA0102;Uhlivska;Углівська;Угловский
UA0104001;UA0104;Aromatnivska;Ароматнівська;Ароматновский
UA0104003;UA0104;Bahativska;Багатівська;Богатовский
UA0104005;UA0104;Bilohirska;Білогірська;Белогорский
UA0104007;UA0104;Vasylivska;Василівська;Васильевский
UA0104009;UA0104;Vyshenska;Вишенська;Вишенский
UA0104011;UA0104;Drofynska;Дрофинська;Дрофинский
UA0104013;UA0104;Zheliabovska;Желябовська;Желябовский
UA0104015;UA0104;Zhemchuzhynska;Жемчужинська;Жемчужинский
UA0104017;UA0104;Zelenohirska;Зеленогірська;Зеленогорский
UA0104019;UA0104;Zemlianychnenska;Земляничненська;Земляничненский
UA0104021;UA0104;Zybynska;Зибинська;Зыбинский
UA0104023;UA0104;Zorkinska;Зоркінська;Зоркинский
UA0104025;UA0104;Zuiska;Зуйська;Зуйский
UA0104027;UA0104;Ivanivska;Іванівська;Ивановский
UA0104029;UA0104;Izobilnenska;Ізобільненська;Изобильненский
UA0104031;UA0104;Kistochkivska;Кісточківська;Косточковский
UA0104033;UA0104;Krymskorozivska;Кримськорозівська;Крымскорозовский
UA0104035;UA0104;Krynychnenska;Криничненська;Криничненский
UA0104037;UA0104;Kurska;Курська;Курский
UA0104039;UA0104;Lystvynska;Листвинська;Лиственский
UA0104041;UA0104;Melnychna;Мельнична;Мельничный
UA0104043;UA0104;Mytrofanivska;Митрофанівська;Митрофановский
UA0104045;UA0104;Mykhailivska;Михайлівська;Михайловский
UA0104047;UA0104;Michurinska;Мічурінська;Мичуринский
UA0104049;UA0104;Muromska;Муромська;Муромский
UA0104051;UA0104;Nyzhnohirska;Нижньогірська;Нижнегорский
UA0104053;UA0104;Novohryhorivska;Новогригорівська;Новогригорьевский
UA0104055;UA0104;Novozhylivska;Новожилівська;Новожиловский
UA0104057;UA0104;Omelianivska;Омелянівська;Емельяновский
UA0104059;UA0104;Okhotska;Охотська;Охотский
UA0104061;UA0104;Pshenychnenska;Пшеничненська;Пшеничненский
UA0104063;UA0104;Rusakivska;Русаківська;Русаковский
UA0104065;UA0104;Sadova;Садова;Садовый
UA0104067;UA0104;Uvarivska;Уварівська;Уваровский
UA0104069;UA0104;Tsvitochnenska;Цвіточненська;Цветочненский
UA0104071;UA0104;Chkalovska;Чкаловська;Чкаловский
UA0104073;UA0104;Chornopilska;Чорнопільська;Чернопольский
UA0104075;UA0104;Yakymivska;Якимівська;Акимовский
UA0106001;UA0106;Azovska;Азовська;Азовский
UA0106003;UA0106;Vilnenska;Вільненська;Вольненский
UA0106005;UA0106;Dzhankoiska;Джанкойська;Джанкойский
UA0106007;UA0106;Yermakivska;Єрмаківська;Ермаковский
UA0106009;UA0106;Zavito-Leninska;Завіто-Ленінська;Завето-Ленинский
UA0106011;UA0106;Zarichnenska;Зарічненська;Заречненский
UA0106013;UA0106;Izumrudnivska;Ізумруднівська;Изумрудновский
UA0106015;UA0106;Kindrativska;Кіндратівська;Кондратьевский
UA0106017;UA0106;Krymkivska;Кримківська;Крымковский
UA0106019;UA0106;Lobanivska;Лобанівська;Лобановский
UA0106021;UA0106;Luhanska;Луганська;Луганский
UA0106023;UA0106;Maiska;Майська;Майский
UA0106025;UA0106;Maslivska;Маслівська;Масловский
UA0106027;UA0106;Medvedivska;Медведівська;Медведевский
UA0106029;UA0106;Myrnivska;Мирнівська;Мирновский
UA0106031;UA0106;Novokrymska;Новокримська;Новокрымский
UA0106033;UA0106;Pakharivska;Пахарівська;Пахаревский
UA0106035;UA0106;Pobiednenska;Побєдненська;Победненский
UA0106037;UA0106;Prostornenska;Просторненська;Просторненский
UA0106039;UA0106;Rozkishnenska;Розкішненська;Роскошненский
UA0106041;UA0106;Roshchynska;Рощинська;Рощинский
UA0106043;UA0106;Svitlivska;Світлівська;Светловский
UA0106045;UA0106;Stalnenska;Стальненська;Стальненский
UA0106047;UA0106;Tabachnenska;Табачненська;Табачненский
UA0106049;UA0106;Tsilynna;Цілинна;Целинный
UA0106051;UA0106;Chaikynska;Чайкинська;Чайкинский
UA0106053;UA0106;Yarkivska;Ярківська;Ярковский
UA0106055;UA0106;Yarkopolenska;Яркополенська;Яркополенский
UA0106057;UA0106;Yasnopolianska;Яснополянська;Яснополянский
UA0108001;UA0108;Veresaievska;Вересаєвська;Вересаевский
UA0108003;UA0108;Veselivska;Веселівська;Веселовский
UA0108005;UA0108;Vynohradivska;Виноградівська;Виноградовский
UA0108007;UA0108;Vorobiovska;Воробйовська;Воробьевский
UA0108009;UA0108;Heroiska;Геройська;Геройский
UA0108011;UA0108;Dalekivska;Далеківська;Далековский
UA0108013;UA0108;Dobrushynska;Добрушинська;Добрушинский
UA0108015;UA0108;Yevpatoriiska;Євпаторійська;Евпаторийский
UA0108017;UA0108;Zaozernenska;Заозерненська;Заозерненский
UA0108019;UA0108;Zernivska;Зернівська;Зерновский
UA0108021;UA0108;Ivanivska;Іванівська;Ивановский
UA0108023;UA0108;Kirovska;Кіровська;Кировский
UA0108025;UA0108;Koltsovska;Кольцовська;Кольцовский
UA0108027;UA0108;Krainenska;Крайненська;Крайненский
UA0108029;UA0108;Krasnopolianska;Краснополянська;Краснополянский
UA0108031;UA0108;Krasnoiarska;Красноярська;Красноярский
UA0108033;UA0108;Krymska;Кримська;Крымский
UA0108035;UA0108;Lisnivska;Ліснівська;Лесновский
UA0108037;UA0108;Medvedivska;Медведівська;Медведевский
UA0108039;UA0108;Myrnivska;Мирнівська;Мирновский
UA0108041;UA0108;Mytiaivska;Митяївська;Митяевский
UA0108043;UA0108;Mizhvodnenska;Міжводненська;Межводненский
UA0108045;UA0108;Molochnenska;Молочненська;Молочненский
UA0108047;UA0108;Novoivanivska;Новоіванівська;Новоивановский
UA0108049;UA0108;Novoozernivska;Новоозернівська;Новоозерновский
UA0108051;UA0108;Novosilska;Новосільська;Новосельский
UA0108053;UA0108;Novofedorivska;Новофедорівська;Новофедоровский
UA0108055;UA0108;Okunivska;Окунівська;Окуневский
UA0108057;UA0108;Olenivska;Оленівська;Оленевский
UA0108059;UA0108;Orikhivska;Оріхівська;Ореховский
UA0108061;UA0108;Okhotnykivska;Охотниківська;Охотниковский
UA0108063;UA0108;Romashkinska;Ромашкінська;Ромашкинский
UA0108065;UA0108;Sakska;Сакська;Сакский
UA0108067;UA0108;Syzivska;Сизівська;Сизовский
UA0108069;UA0108;Stovpivska;Стовпівська;Столбовский
UA0108071;UA0108;Suvorovska;Суворовська;Суворовский
UA0108073;UA0108;Uiutnenska;Уютненська;Уютненский
UA0108075;UA0108;Frunzenska;Фрунзенська;Фрунзенский
UA0108077;UA0108;Chornomorska;Чорноморська;Черноморский
UA0108079;UA0108;Shtormivska;Штормівська;Штормовский
UA0110001;UA0110;Baherivska;Багерівська;Багеровский
UA0110003;UA0110;Batalnenska;Батальненська;Батальненский
UA0110005;UA0110;Bielinska;Бєлінська;Белинский
UA0110007;UA0110;Vynohradnenska;Виноградненська;Виноградненский
UA0110009;UA0110;Voikovska;Войковська;Войковский
UA0110011;UA0110;Hlazivska;Глазівська;Глазовский
UA0110013;UA0110;Hornostaivska;Горностаївська;Горностаевский
UA0110015;UA0110;Zavitnenska;Завітненська;Заветненский
UA0110017;UA0110;Illichivska;Іллічівська;Ильичовский
UA0110019;UA0110;Kalynivska;Калинівська;Калиновский
UA0110021;UA0110;Kerchenska;Керченська;Керченский
UA0110023;UA0110;Kirovska;Кіровська;Кировский
UA0110025;UA0110;Krasnohirska;Красногірська;Красногорский
UA0110027;UA0110;Leninska;Ленінська;Ленинский
UA0110029;UA0110;Leninska;Ленінська;Ленинский
UA0110031;UA0110;Luhivska;Лугівська;Луговский
UA0110033;UA0110;Marivska;Мар'ївська;Марьевский
UA0110035;UA0110;Marfivska;Марфівська;Марфовский
UA0110037;UA0110;Mysivska;Мисівська;Мысовский
UA0110039;UA0110;Novomykolaivska;Новомиколаївська;Новониколаевский
UA0110041;UA0110;Oktiabrska;Октябрська;Октябрьский
UA0110043;UA0110;Ostaninska;Останінська;Останинский
UA0110045;UA0110;Pryozernivska;Приозернівська;Приозерновский
UA0110047;UA0110;Semysotska;Семисотська;Семисотский
UA0110049;UA0110;Uvarivska;Уварівська;Уваровский
UA0110051;UA0110;Cheliadinivska;Челядінівська;Челядиновский
UA0110053;UA0110;Chystopilska;Чистопільська;Чистопольский
UA0110055;UA0110;Shcholkinska;Щолкінська;Щелкинский
UA0112001;UA0112;Abrykosivska;Абрикосівська;Абрикосовский
UA0112003;UA0112;Amurska;Амурська;Амурский
UA0112005;UA0112;Voikovska;Войковська;Войковский
UA0112007;UA0112;Voskhodnenska;Восходненська;Восходненский
UA0112009;UA0112;Hvardiiska;Гвардійська;Гвардейский
UA0112011;UA0112;Hryshynska;Гришинська;Гришинский
UA0112013;UA0112;Zernivska;Зернівська;Зерновский
UA0112015;UA0112;Kalininska;Калінінська;Калининский
UA0112017;UA0112;Kalininska;Калінінська;Калининский
UA0112019;UA0112;Klepyninska;Клепинінська;Клепининский
UA0112021;UA0112;Kolodiazianska;Колодязянська;Колодезянский
UA0112023;UA0112;Kormivska;Кормівська;Кормовской
UA0112025;UA0112;Kotelnykivska;Котельниківська;Котельниковский
UA0112027;UA0112;Krasnohvardiiska;Красногвардійська;Красногвардейский
UA0112029;UA0112;Krasnoznamianska;Краснознам'янська;Краснознаменский
UA0112031;UA0112;Krestianivska;Крестянівська;Крестьяновский
UA0112033;UA0112;Leninska;Ленінська;Ленинский
UA0112035;UA0112;Marianivska;Мар'янівська;Марьяновский
UA0112037;UA0112;Naidonivska;Найдьонівська;Найденовский
UA0112039;UA0112;Novopokrovska;Новопокровська;Новопокровский
UA0112041;UA0112;Oktiabrska;Октябрська;Октябрьский
UA0112043;UA0112;Oktiabrska;Октябрська;Октябрьский
UA0112045;UA0112;Oleksandrivska;Олександрівська;Александровский
UA0112047;UA0112;Oleksiivska;Олексіївська;Алексеевский
UA0112049;UA0112;Ostrovska;Островська;Островский
UA0112051;UA0112;Piatykhatska;П'ятихатська;Пятихатский
UA0112053;UA0112;Pervomaiska;Первомайська;Первомайский
UA0112055;UA0112;Petrivska;Петрівська;Петровский
UA0112057;UA0112;Poltavska;Полтавська;Полтавский
UA0112059;UA0112;Pravdivska;Правдівська;Правдовский
UA0112061;UA0112;Rivnivska;Рівнівська;Ровновский
UA0112063;UA0112;Sarybashivska;Сарибашівська;Сарыбащевский
UA0112065;UA0112;Stakhanovska;Стахановська;Стахановский
UA0112067;UA0112;Stepnivska;Степнівська;Степновский
UA0112069;UA0112;Susaninska;Сусанінська;Сусанинский
UA0112071;UA0112;Chernovska;Черновська;Черновский
UA0112073;UA0112;Yantarnenska;Янтарненська;Янтарненский
UA0114001;UA0114;Armianska;Армянська;Армянский
UA0114003;UA0114;Berezivska;Березівська;Березовский
UA0114005;UA0114;Botanichna;Ботанічна;Ботанический
UA0114007;UA0114;Bratska;Братська;Братский
UA0114009;UA0114;Vyshnivska;Вишнівська;Вишневский
UA0114011;UA0114;Voinska;Воїнська;Воинский
UA0114013;UA0114;Zymynska;Зиминська;Зиминский
UA0114015;UA0114;Illinska;Іллінська;Ильинский
UA0114017;UA0114;Ishunska;Ішунська;Ишунский
UA0114019;UA0114;Kovylnivska;Ковильнівська;Ковыльновский
UA0114021;UA0114;Krasnoarmiiska;Красноармійська;Красноармейский
UA0114023;UA0114;Krasnoperekopska;Красноперекопська;Красноперекопский
UA0114025;UA0114;Kukushkinska;Кукушкінська;Кукушкинский
UA0114027;UA0114;Mahazynska;Магазинська;Магазинский
UA0114029;UA0114;Novopavlivska;Новопавлівська;Новопавловский
UA0114031;UA0114;Novoselivska;Новоселівська;Новоселовский
UA0114033;UA0114;Orlivska;Орлівська;Орловский
UA0114035;UA0114;Pochetnenska;Почетненська;Почетненский
UA0114037;UA0114;Rozdolnenska;Роздольненська;Роздольненский
UA0114039;UA0114;Ruchivska;Руч'ївська;Ручьевский
UA0114041;UA0114;Serebrianska;Серебрянська;Серебрянский
UA0114043;UA0114;Slavnivska;Славнівська;Славновский
UA0114045;UA0114;Slovianska;Слов'янська;Славянский
UA0114047;UA0114;Sovkhoznenska;Совхозненська;Совхозненский
UA0114049;UA0114;Suvorovska;Суворовська;Суворовский
UA0114051;UA0114;Filativska;Філатівська;Филатовский
UA0114053;UA0114;Chernyshivska;Чернишівська;Чернышевский
UA0116001;UA0116;Hvardiiska;Гвардійська;Гвардейский
UA0116003;UA0116;Hresivska;Гресівська;Грэсовский
UA0116005;UA0116;Dobrivska;Добрівська;Добровский
UA0116007;UA0116;Donska;Донська;Донской
UA0116009;UA0116;Zhuravlivska;Журавлівська;Журавлевский
UA0116011;UA0116;Kolchuhynska;Кольчугинська;Кольчугинский
UA0116013;UA0116;Mazanska;Мазанська;Мазанский
UA0116015;UA0116;Mykolaivska;Миколаївська;Николаевский
UA0116017;UA0116;Myrnivska;Мирнівська;Мирновский
UA0116019;UA0116;Molodizhnenska;Молодіжненська;Молодежненский
UA0116021;UA0116;Novoandriivska;Новоандріївська;Новоандреевский
UA0116023;UA0116;Novoselivska;Новоселівська;Новоселовский
UA0116025;UA0116;Pervomaiska;Первомайська;Первомайский
UA0116027;UA0116;Perovska;Перовська;Перовский
UA0116029;UA0116;Pozharska;Пожарська;Пожарский
UA0116031;UA0116;Rodnykivska;Родниківська;Родниковский
UA0116033;UA0116;Simferopolska;Сімферопольська;Симферопольский
UA0116035;UA0116;Skvortsivska;Скворцівська;Скворцовский
UA0116037;UA0116;Trudivska;Трудівська;Трудовский
UA0116039;UA0116;Ukromnivska;Укромнівська;Укромновский
UA0116041;UA0116;Urozhainivska;Урожайнівська;Урожайновский
UA0116043;UA0116;Chystenska;Чистенська;Чистенский
UA0116045;UA0116;Shyrokivska;Широківська;Широковский
UA0116047;UA0116;Shkilnenska;Шкільненська;Школьненский
UA0118001;UA0118;Abrykosivska;Абрикосівська;Абрикосовский
UA0118003;UA0118;Berehova;Берегова;Береговой
UA0118005;UA0118;Veselivska;Веселівська;Веселовский
UA0118007;UA0118;Vladyslavivska;Владиславівська;Владиславовский
UA0118009;UA0118;Hrushivska;Грушівська;Грушевский
UA0118011;UA0118;Dachnivska;Дачнівська;Дачновский
UA0118013;UA0118;Dmytrivska;Дмитрівська;Дмитровский
UA0118015;UA0118;Zhuravska;Журавська;Журавский
UA0118017;UA0118;Zavitnenska;Завітненська;Заветненский
UA0118019;UA0118;Zolotopolenska;Золотополенська;Золотополенский
UA0118021;UA0118;Illichivska;Іллічівська;Ильичовский
UA0118023;UA0118;Kirovska;Кіровська;Кировский
UA0118025;UA0118;Koktebelska;Коктебельська;Коктебельский
UA0118027;UA0118;Krasnohvardiiska;Красногвардійська;Красногвардейский
UA0118029;UA0118;Krasnoflotska;Краснофлотська;Краснофлотский
UA0118031;UA0118;Lhovska;Льговська;Льговский
UA0118033;UA0118;Mizhrichenska;Міжріченська;Междуреченский
UA0118035;UA0118;Morska;Морська;Морской
UA0118037;UA0118;Nasypnivska;Насипнівська;Насыпновский
UA0118039;UA0118;Nekrasovska;Некрасовська;Некрасовский
UA0118041;UA0118;Novosvitska;Новосвітська;Новосветский
UA0118043;UA0118;Ordzhonikidzevska;Орджонікідзевська;Орджоникидзевский
UA0118045;UA0118;Partyzanska;Партизанська;Партизанский
UA0118047;UA0118;Pervomaiska;Первомайська;Первомайский
UA0118049;UA0118;Pryvitnenska;Привітненська;Приветненский
UA0118051;UA0118;Prymorska;Приморська;Приморский
UA0118053;UA0118;Prudivska;Прудівська;Прудовский
UA0118055;UA0118;Pushkinska;Пушкінська;Пушкинский
UA0118057;UA0118;Synytsynska;Синицинська;Синицынский
UA0118059;UA0118;Sovietska;Совєтська;Советский
UA0118061;UA0118;Soniachnodolynska;Сонячнодолинська;Солнечнодолинский
UA0118063;UA0118;Starokrymska;Старокримська;Старокрымский
UA0118065;UA0118;Sudatska;Судацька;Судакский
UA0118067;UA0118;Tokarievska;Токарєвська;Токаревский
UA0118069;UA0118;Urozhainivska;Урожайнівська;Урожайновский
UA0118071;UA0118;Feodosiiska;Феодосійська;Феодосийский
UA0118073;UA0118;Chapaievska;Чапаєвська;Чапаевский
UA0118075;UA0118;Chornozemnenska;Чорноземненська;Черноземненский
UA0118077;UA0118;Shchebetovska;Щебетовська;Щебетовский
UA0118079;UA0118;Yarkopolenska;Яркополенська;Яркополенский
UA0120001;UA0120;Alupkynska;Алупкинська;Алупкинский
UA0120003;UA0120;Alushtynska;Алуштинська;Алуштинский
UA0120005;UA0120;Hasprynska;Гаспринська;Гаспринский
UA0120007;UA0120;Hurzufska;Гурзуфська;Гурзуфский
UA0120009;UA0120;Izobilnenska;Ізобільненська;Изобильненский
UA0120011;UA0120;Koreizka;Кореїзька;Кореизский
UA0120013;UA0120;Livadiiska;Лівадійська;Ливадийский
UA0120015;UA0120;Luchystivska;Лучистівська;Лучистовский
UA0120017;UA0120;Malomaiatska;Маломаяцька;Маломаякский
UA0120019;UA0120;Malorichenska;Малоріченська;Малореченский
UA0120021;UA0120;Masandrivska;Масандрівська;Массандровский
UA0120023;UA0120;Partenitska;Партенітська;Партенитский
UA0120025;UA0120;Pryvitnenska;Привітненська;Приветненский
UA0120027;UA0120;Simeizka;Сімеїзька;Симеизский
UA0120029;UA0120;Foroska;Фороська;Форосский
UA0120031;UA0120;Yaltynska;Ялтинська;Ялтинский
UA0502001;UA0502;Ahronomichna;Агрономічна;Агрономическая
UA0502003;UA0502;Vinnytska;Вінницька;Винницкая
UA0502005;UA0502;Voronovytska;Вороновицька;Вороновицкая
UA0502007;UA0502;Hnivanska;Гніванська;Гниваньская
UA0502009;UA0502;Illinetska;Іллінецька;Ильинецкая
UA0502011;UA0502;Lypovetska;Липовецька;Липовецкая
UA0502013;UA0502;Litynska;Літинська;Литинская
UA0502015;UA0502;Luka-Meleshkivska;Лука-Мелешківська;Лука-Мелешковская
UA0502017;UA0502;Nemyrivska;Немирівська;Нимировская
UA0502019;UA0502;Orativska;Оратівська;Оратовская
UA0502021;UA0502;Pohrebyshchenska;Погребищенська;Погребищенская
UA0502023;UA0502;Stryzhavska;Стрижавська;Стрижавская
UA0502025;UA0502;Sutyskivska;Сутисківська;Сутисковская
UA0502027;UA0502;Tyvrivska;Тиврівська;Тывровская
UA0502029;UA0502;Turbivska;Турбівська;Турбовская
UA0502031;UA0502;Yakushynetska;Якушинецька;Якушинецкая
UA0504001;UA0504;Bershadska;Бершадська;Бершадская
UA0504003;UA0504;Haisynska;Гайсинська;Гайсинская
UA0504005;UA0504;Dashivska;Дашівська;Дашевская
UA0504007;UA0504;Dzhulynska;Джулинська;Джулинская
UA0504009;UA0504;Krasnopilska;Краснопільська;Краснопольская
UA0504011;UA0504;Kunkivska;Кунківська;Кунковская
UA0504013;UA0504;Ladyzhynska;Ладижинська;Ладыжинская
UA0504015;UA0504;Obodivska;Ободівська;Ободовская
UA0504017;UA0504;Olhopilska;Ольгопільська;Ольгопольская
UA0504019;UA0504;Raihorodska;Райгородська;Райгородская
UA0504021;UA0504;Sobolivska;Соболівська;Соболевская
UA0504023;UA0504;Teplytska;Теплицька;Тепликская
UA0504025;UA0504;Trostianetska;Тростянецька;Тростянецкая
UA0504027;UA0504;Chechelnytska;Чечельницька;Чечельницкая
UA0506001;UA0506;Barska;Барська;Барская
UA0506003;UA0506;Dzhurynska;Джуринська;Джуринская
UA0506005;UA0506;Zhmerynska;Жмеринська;Жмеринская
UA0506007;UA0506;Kopaihorodska;Копайгородська;Копайгородская
UA0506009;UA0506;Murafska;Мурафська;Мурафская
UA0506011;UA0506;Severynivska;Северинівська;Севериновская
UA0506013;UA0506;Stanislavchytska;Станіславчицька;Станиславчикская
UA0506015;UA0506;Sharhorodska;Шаргородська;Шаргородская
UA0508001;UA0508;Babchynetska;Бабчинецька;Бабчинецкая
UA0508003;UA0508;Vendychanska;Вендичанська;Вендичанская
UA0508005;UA0508;Mohyliv-Podilska;Могилів-Подільська;Могилев-Подольская
UA0508007;UA0508;Murovanokurylovetska;Мурованокуриловецька;Мурованокуриловецкая
UA0508009;UA0508;Chernivetska;Чернівецька;Черневецкая
UA0508011;UA0508;Yampilska;Ямпільська;Ямпольская
UA0508013;UA0508;Yaryshivska;Яришівська;Ярышевская
UA0510001;UA0510;Bratslavska;Брацлавська;Брацлавская
UA0510003;UA0510;Vapniarska;Вапнярська;Вапнярская
UA0510005;UA0510;Horodkivska;Городківська;Городковская
UA0510007;UA0510;Kryzhopilska;Крижопільська;Крыжопольская
UA0510009;UA0510;Pishchanska;Піщанська;Песчанская
UA0510011;UA0510;Studenianska;Студенянська;Студенянская
UA0510013;UA0510;Tomashpilska;Томашпільська;Томашпольская
UA0510015;UA0510;Tulchynska;Тульчинська;Тульчинская
UA0510017;UA0510;Shpykivska;Шпиківська;Шпиковская
UA0512001;UA0512;Hlukhovetska;Глуховецька;Глуховецкая
UA0512003;UA0512;Zhdanivska;Жданівська;Ждановская
UA0512005;UA0512;Ivanivska;Іванівська;Ивановская
UA0512007;UA0512;Kalynivska;Калинівська;Калиновская
UA0512009;UA0512;Koziatynska;Козятинська;Казатинская
UA0512011;UA0512;Makhnivska;Махнівська;Махновская
UA0512013;UA0512;Samhorodotska;Самгородоцька;Самгородокская
UA0512015;UA0512;Ulanivska;Уланівська;Улановская
UA0512017;UA0512;Khmilnytska;Хмільницька;Хмельницкая
UA0702001;UA0702;Volodymyr-Volynska;Володимир-Волинська;Владимир-Волынская
UA0702003;UA0702;Zaturtsivska;Затурцівська;Затурцевская
UA0702005;UA0702;Zymnivska;Зимнівська;Зимневская
UA0702007;UA0702;Ivanychivska;Іваничівська;Иваничевская
UA0702009;UA0702;Lytovezka;Литовезька;Литовежская
UA0702011;UA0702;Lokachynska;Локачинська;Локачинская
UA0702013;UA0702;Novovolynska;Нововолинська;Нововолынская
UA0702015;UA0702;Ovadnivska;Оваднівська;Овадновская
UA0702017;UA0702;Pavlivska;Павлівська;Павловская
UA0702019;UA0702;Poromivska;Поромівська;Поромовская
UA0702021;UA0702;Ustyluzka;Устилузька;Устилугская
UA0704001;UA0704;Kamin-Kashyrska;Камінь-Каширська;Камень-Каширская
UA0704003;UA0704;Liubeshivska;Любешівська;Любешовская
UA0704005;UA0704;Manevytska;Маневицька;Маневичская
UA0704007;UA0704;Prylisnenska;Прилісненська;Прилесненская
UA0704009;UA0704;Soshychnenska;Сошичненська;Сошичненская
UA0706001;UA0706;Velymchenska;Велимченська;Велимченская
UA0706003;UA0706;Velytska;Велицька;Велицкая
UA0706005;UA0706;Vyshnivska;Вишнівська;Вишневская
UA0706007;UA0706;Holobska;Голобська;Голобская
UA0706009;UA0706;Holovnenska;Головненська;Головненская
UA0706011;UA0706;Dubechnenska;Дубечненська;Дубечненская
UA0706013;UA0706;Dubivska;Дубівська;Дубовская
UA0706015;UA0706;Zabolottivska;Заболоттівська;Заболотьевская
UA0706017;UA0706;Zabrodivska;Забродівська;Забродовская
UA0706019;UA0706;Kovelska;Ковельська;Ковельская
UA0706021;UA0706;Kolodiazhnenska;Колодяжненська;Колодежненская
UA0706023;UA0706;Lukivska;Луківська;Луковская
UA0706025;UA0706;Liublynetska;Люблинецька;Люблинецкая
UA0706027;UA0706;Liubomlska;Любомльська;Любомльская
UA0706029;UA0706;Povorska;Поворська;Поворская
UA0706031;UA0706;Ratnivska;Ратнівська;Ратновская
UA0706033;UA0706;Rivnenska;Рівненська;Ровенская
UA0706035;UA0706;Samarivska;Самарівська;Самаровская
UA0706037;UA0706;Serekhovychivska;Сереховичівська;Сереховичевская
UA0706039;UA0706;Smidynska;Смідинська;Смидинская
UA0706041;UA0706;Starovyzhivska;Старовижівська;Старовыжевская
UA0706043;UA0706;Turiiska;Турійська;Турийская
UA0706045;UA0706;Shatska;Шацька;Шацкая
UA0708001;UA0708;Berestechkivska;Берестечківська;Берестечковская
UA0708003;UA0708;Boratynska;Боратинська;Боратинская
UA0708005;UA0708;Horodyshchenska;Городищенська;Городищенская
UA0708007;UA0708;Horokhivska;Горохівська;Гороховская
UA0708009;UA0708;Dorosynivska;Доросинівська;Доросиневская
UA0708011;UA0708;Kivertsivska;Ківерцівська;Киверцовская
UA0708013;UA0708;Kolkivska;Колківська;Колковская
UA0708015;UA0708;Kopachivska;Копачівська;Копачовская
UA0708017;UA0708;Lutska;Луцька;Луцкая
UA0708019;UA0708;Marianivska;Мар'янівська;Марьяновская
UA0708021;UA0708;Olytska;Олицька;Олыкская
UA0708023;UA0708;Pidhaitsivska;Підгайцівська;Подгайцевская
UA0708025;UA0708;Rozhyshchenska;Рожищенська;Рожищенская
UA0708027;UA0708;Torchynska;Торчинська;Торчинская
UA0708029;UA0708;Tsumanska;Цуманська;Цуманская
UA1202001;UA1202;Dniprovska;Дніпровська;Днепровская
UA1202003;UA1202;Kytaihorodska;Китайгородська;Китайгородская
UA1202005;UA1202;Liubymivska;Любимівська;Любимовская
UA1202007;UA1202;Liashkivska;Ляшківська;Ляшковская
UA1202009;UA1202;Mykolaivska;Миколаївська;Николаевская
UA1202011;UA1202;Mohylivska;Могилівська;Могилевская
UA1202013;UA1202;Novooleksandrivska;Новоолександрівська;Новоалександровская
UA1202015;UA1202;Novopokrovska;Новопокровська;Новопокровская
UA1202017;UA1202;Obukhivska;Обухівська;Обуховская
UA1202019;UA1202;Petrykivska;Петриківська;Петриковская
UA1202021;UA1202;Pidhorodnenska;Підгородненська;Подгородненская
UA1202023;UA1202;Sviatovasylivska;Святовасилівська;Святовасильевская
UA1202025;UA1202;Slobozhanska;Слобожанська;Слобожанская
UA1202027;UA1202;Solonianska;Солонянська;Солонянская
UA1202029;UA1202;Sursko-Lytovska;Сурсько-Литовська;Сурско-Литовская
UA1202031;UA1202;Tsarychanska;Царичанська;Царичанская
UA1202033;UA1202;Chumakivska;Чумаківська;Чумаковская
UA1204001;UA1204;Bozhedarivska;Божедарівська;Божедаровская
UA1204003;UA1204;Verkhivtsivska;Верхівцівська;Верховцевская
UA1204005;UA1204;Verkhnodniprovska;Верхньодніпровська;Верхнеднепровская
UA1204007;UA1204;Vyshnivska;Вишнівська;Вишневская
UA1204009;UA1204;Vilnohirska;Вільногірська;Вольногорская
UA1204011;UA1204;Zhovtovodska;Жовтоводська;Желтоводская
UA1204013;UA1204;Zatyshnianska;Затишнянська;Затишнянская
UA1204015;UA1204;Kamianska;Кам'янська;Каменская
UA1204017;UA1204;Krynychanska;Криничанська;Криничанская
UA1204019;UA1204;Lykhivska;Лихівська;Лиховская
UA1204021;UA1204;Piatykhatska;П'ятихатська;Пятихатская
UA1204023;UA1204;Saksahanska;Саксаганська;Саксаганская
UA1206001;UA1206;Apostolivska;Апостолівська;Апостоловская
UA1206003;UA1206;Vakulivska;Вакулівська;Вакуловская
UA1206005;UA1206;Hleiuvatska;Глеюватська;Глееватская
UA1206007;UA1206;Hrechanopodivska;Гречаноподівська;Гречаноподовская
UA1206009;UA1206;Hrushivska;Грушівська;Грушевская
UA1206011;UA1206;Devladivska;Девладівська;Девладовская
UA1206013;UA1206;Zelenodolska;Зеленодольська;Зеленодольская
UA1206015;UA1206;Karpivska;Карпівська;Карповcкая
UA1206017;UA1206;Kryvorizka;Криворізька;Криворожская
UA1206019;UA1206;Lozuvatska;Лозуватська;Лозоватская
UA1206021;UA1206;Nyvotrudivska;Нивотрудівська;Нивотрудовская
UA1206023;UA1206;Novolativska;Новолатівська;Новолатовская
UA1206025;UA1206;Novopilska;Новопільська;Новопольская
UA1206027;UA1206;Sofiivska;Софіївська;Софиевская
UA1206029;UA1206;Shyrokivska;Широківська;Широковская
UA1208001;UA1208;Marhanetska;Марганецька;Марганецкая
UA1208003;UA1208;Myrivska;Мирівська;Мировская
UA1208005;UA1208;Nikopolska;Нікопольська;Никопольская
UA1208007;UA1208;Pershotravnevska;Першотравневська;Першотравневская
UA1208009;UA1208;Pokrovska;Покровська;Покровская
UA1208011;UA1208;Pokrovska;Покровська;Покровская
UA1208013;UA1208;Tomakivska;Томаківська;Томановская
UA1208015;UA1208;Chervonohryhorivska;Червоногригорівська;Червоногригоровская
UA1210001;UA1210;Hubynyska;Губиниська;Губинихская
UA1210003;UA1210;Lychkivska;Личківська;Лычковская
UA1210005;UA1210;Mahdalynivska;Магдалинівська;Мигдалиновская
UA1210007;UA1210;Novomoskovska;Новомосковська;Новомосковская
UA1210009;UA1210;Pereshchepynska;Перещепинська;Перещепинская
UA1210011;UA1210;Pishchanska;Піщанська;Песчанская
UA1210013;UA1210;Cherkaska;Черкаська;Черкасская
UA1210015;UA1210;Chernechchynska;Чернеччинська;Чернетчинская
UA1212001;UA1212;Bohdanivska;Богданівська;Богдановская
UA1212003;UA1212;Verbkivska;Вербківська;Вербковская
UA1212005;UA1212;Mezhyritska;Межиріцька;Межиричская
UA1212007;UA1212;Pavlohradska;Павлоградська;Павлоградская
UA1212009;UA1212;Ternivska;Тернівська;Терновская
UA1212011;UA1212;Troitska;Троїцька;Троицкая
UA1212013;UA1212;Yurivska;Юр'ївська;Юрьевская
UA1214001;UA1214;Brahynivska;Брагинівська;Брагиновская
UA1214003;UA1214;Vasylkivska;Васильківська;Васильковская
UA1214005;UA1214;Velykomykhailivska;Великомихайлівська;Великомихайловская
UA1214007;UA1214;Dubovykivska;Дубовиківська;Дубовикивская
UA1214009;UA1214;Zaitsivska;Зайцівська;Зайцевская
UA1214011;UA1214;Ilarionivska;Іларіонівська;Илларионовская
UA1214013;UA1214;Malomykhailivska;Маломихайлівська;Маломихайловская
UA1214015;UA1214;Mezhivska;Межівська;Межевская
UA1214017;UA1214;Mykolaivska;Миколаївська;Николаевская
UA1214019;UA1214;Novopavlivska;Новопавлівська;Новопавловская
UA1214021;UA1214;Pershotravenska;Першотравенська;Першотравенская
UA1214023;UA1214;Petropavlivska;Петропавлівська;Петропавловская
UA1214025;UA1214;Pokrovska;Покровська;Покровская
UA1214027;UA1214;Raivska;Раївська;Раевская
UA1214029;UA1214;Rozdorska;Роздорська;Раздорская
UA1214031;UA1214;Synelnykivska;Синельниківська;Синельниковская
UA1214033;UA1214;Slavhorodska;Славгородська;Славгородская
UA1214035;UA1214;Slovianska;Слов'янська;Славянская
UA1214037;UA1214;Ukrainska;Українська;Украинская
UA1402001;UA1402;Bakhmutska;Бахмутська;Бахмутская
UA1402003;UA1402;Zvanivska;Званівська;Звановская
UA1402005;UA1402;Svitlodarska;Світлодарська;Светлодарская
UA1402007;UA1402;Siverska;Сіверська;Северская
UA1402009;UA1402;Soledarska;Соледарська;Соледарская
UA1402011;UA1402;Toretska;Торецька;Торецкая
UA1402013;UA1402;Chasovoiarska;Часовоярська;Часовоярская
UA1404001;UA1404;Velykonovosilkivska;Великоновосілківська;Великоновоселковская
UA1404003;UA1404;Volnovaska;Волноваська;Волновахская
UA1404005;UA1404;Vuhledarska;Вугледарська;Угледарская
UA1404007;UA1404;Komarska;Комарська;Комарская
UA1404009;UA1404;Myrnenska;Мирненська;Мирненская
UA1404011;UA1404;Olhynska;Ольгинська;Ольгинская
UA1404013;UA1404;Staromlynivska;Старомлинівська;Старомлыновская
UA1404015;UA1404;Khlibodarivska;Хлібодарівська;Хлебодаровская
UA1406001;UA1406;Vuhlehirska;Вуглегірська;Углегорская
UA1406003;UA1406;Horlivska;Горлівська;Горловская
UA1406005;UA1406;Debaltsivska;Дебальцівська;Дебальцевская
UA1406007;UA1406;Yenakiievska;Єнакієвська;Енакиевская
UA1406009;UA1406;Zhdanivska;Жданівська;Ждановская
UA1406011;UA1406;Snizhnianska;Сніжнянська;Снежнянская
UA1406013;UA1406;Khrestivska;Хрестівська;Крестовская
UA1406015;UA1406;Chystiakivska;Чистяківська;Чистяковская
UA1406017;UA1406;Shakhtarska;Шахтарська;Шахтерская
UA1408001;UA1408;Amvrosiivska;Амвросіївська;Амвросиевская
UA1408003;UA1408;Donetska;Донецька;Донецкая
UA1408005;UA1408;Ilovaiska;Іловайська;Иловайская
UA1408007;UA1408;Makiivska;Макіївська;Макеевская
UA1408009;UA1408;Khartsyzka;Харцизька;Харцызская
UA1408011;UA1408;Yasynuvatska;Ясинуватська;Ясиноватская
UA1410001;UA1410;Boikivska;Бойківська;Бойковская
UA1410003;UA1410;Dokuchaievska;Докучаєвська;Докучаевская
UA1410005;UA1410;Kalmiuska;Кальміуська;Кальмиусская
UA1410007;UA1410;Novoazovska;Новоазовська;Новоазовская
UA1410009;UA1410;Starobeshivska;Старобешівська;Старобешевская
UA1412001;UA1412;Andriivska;Андріївська;Андреевская
UA1412003;UA1412;Druzhkivska;Дружківська;Дружковская
UA1412005;UA1412;Illinivska;Іллінівська;Ильиновская
UA1412007;UA1412;Kostiantynivska;Костянтинівська;Константиновская
UA1412009;UA1412;Kramatorska;Краматорська;Краматорская
UA1412011;UA1412;Lymanska;Лиманська;Лиманская
UA1412013;UA1412;Mykolaivska;Миколаївська;Николаевская
UA1412015;UA1412;Novodonetska;Новодонецька;Новодонецкая
UA1412017;UA1412;Oleksandrivska;Олександрівська;Александровская
UA1412019;UA1412;Sviatohirska;Святогірська;Святогорская
UA1412021;UA1412;Slovianska;Слов'янська;Славянская
UA1412023;UA1412;Cherkaska;Черкаська;Черкасская
UA1414001;UA1414;Kalchytska;Кальчицька;Кальчикская
UA1414003;UA1414;Manhushska;Мангушська;Мангушская
UA1414005;UA1414;Mariupolska;Маріупольська;Мариупольская
UA1414007;UA1414;Nikolska;Нікольська;Никольская
UA1414009;UA1414;Sartanska;Сартанська;Сартанская
UA1416001;UA1416;Avdiivska;Авдіївська;Авдеевская
UA1416003;UA1416;Bilozerska;Білозерська;Белозерская
UA1416005;UA1416;Hrodivska;Гродівська;Гродовская
UA1416007;UA1416;Dobropilska;Добропільська;Добропольская
UA1416009;UA1416;Kryvorizka;Криворізька;Криворожская
UA1416011;UA1416;Kurakhivska;Курахівська;Кураховская
UA1416013;UA1416;Marinska;Мар'їнська;Марьинская
UA1416015;UA1416;Myrnohradska;Мирноградська;Мирноградская
UA1416017;UA1416;Novohrodivska;Новогродівська;Новогродовская
UA1416019;UA1416;Ocheretynska;Очеретинська;Очеретинская
UA1416021;UA1416;Pokrovska;Покровська;Покровская
UA1416023;UA1416;Selydivska;Селидівська;Селидовская
UA1416025;UA1416;Udachnenska;Удачненська;Удачненская
UA1416027;UA1416;Shakhivska;Шахівська;Шаховская
UA1802001;UA1802;Andrushivska;Андрушівська;Андрушевская
UA1802003;UA1802;Berdychivska;Бердичівська;Бердичевская
UA1802005;UA1802;Vchoraishenska;Вчорайшенська;Вчерайшенская
UA1802007;UA1802;Hryshkovetska;Гришковецька;Гришковецкая
UA1802009;UA1802;Krasnopilska;Краснопільська;Краснопольская
UA1802011;UA1802;Raihorodotska;Райгородоцька;Райгородокская
UA1802013;UA1802;Ruzhynska;Ружинська;Ружинская
UA1802015;UA1802;Semenivska;Семенівська;Семеновская
UA1802017;UA1802;Chervonenska;Червоненська;Червоненская
UA1802019;UA1802;Shvaikivska;Швайківська;Швайковская
UA1804001;UA1804;Andrushkivska;Андрушківська;Андрушковская
UA1804003;UA1804;Berezivska;Березівська;Березовская
UA1804005;UA1804;Brusylivska;Брусилівська;Брусиловская
UA1804007;UA1804;Vysokivska;Високівська;Высоковская
UA1804009;UA1804;Vyshevytska;Вишевицька;Вышевичская
UA1804011;UA1804;Vilshanska;Вільшанська;Ольшанская
UA1804013;UA1804;Volytska;Волицька;Волицкая
UA1804015;UA1804;Hlybochytska;Глибочицька;Глубочицкая
UA1804017;UA1804;Horodotska;Городоцька;Городецкая
UA1804019;UA1804;Zhytomyrska;Житомирська;Житомирская
UA1804021;UA1804;Kvitneva;Квітнева;Квитневая
UA1804023;UA1804;Kornynska;Корнинська;Корнинская
UA1804025;UA1804;Korostyshivska;Коростишівська;Коростышевская
UA1804027;UA1804;Kurnenska;Курненська;Курненская
UA1804029;UA1804;Liubarska;Любарська;Любарская
UA1804031;UA1804;Myropilska;Миропільська;Миропольская
UA1804033;UA1804;Novoborivska;Новоборівська;Новоборовская
UA1804035;UA1804;Novohuivynska;Новогуйвинська;Новогуйвинская
UA1804037;UA1804;Oliivska;Оліївська;Олиевская
UA1804039;UA1804;Popilnianska;Попільнянська;Попельнянская
UA1804041;UA1804;Potiivska;Потіївська;Потиевская
UA1804043;UA1804;Pulynska;Пулинська;Пулинская
UA1804045;UA1804;Radomyshlska;Радомишльська;Радомышльская
UA1804047;UA1804;Romanivska;Романівська;Романовская
UA1804049;UA1804;Stanyshivska;Станишівська;Станишовская
UA1804051;UA1804;Starosiletska;Старосілецька;Староселецкая
UA1804053;UA1804;Teterivska;Тетерівська;Тетеревская
UA1804055;UA1804;Kharytonivska;Харитонівська;Харитоновская
UA1804057;UA1804;Khoroshivska;Хорошівська;Хорошевская
UA1804059;UA1804;Cherniakhivska;Черняхівська;Черняховская
UA1804061;UA1804;Chudniv;Чуднівська;Чудновская
UA1806001;UA1806;Bilokorovytska;Білокоровицька;Белокоровичская
UA1806003;UA1806;Hladkovytska;Гладковицька;Гладковичская
UA1806005;UA1806;Horshchykivska;Горщиківська;Горщиковская
UA1806007;UA1806;Irshanska;Іршанська;Иршанская
UA1806009;UA1806;Korostenska;Коростенська;Коростенская
UA1806011;UA1806;Luhynska;Лугинська;Лугинская
UA1806013;UA1806;Malynska;Малинська;Малинская
UA1806015;UA1806;Narodytska;Народицька;Народичская
UA1806017;UA1806;Ovrutska;Овруцька;Овручская
UA1806019;UA1806;Olevska;Олевська;Олевская
UA1806021;UA1806;Slovechanska;Словечанська;Словечанская
UA1806023;UA1806;Ushomyrska;Ушомирська;Ушомирская
UA1806025;UA1806;Chopovytska;Чоповицька;Чоповичская
UA1808001;UA1808;Baranivska;Баранівська;Барановская
UA1808003;UA1808;Barashivska;Барашівська;Барашевская
UA1808005;UA1808;Bronykivska;Брониківська;Брониковская
UA1808007;UA1808;Horodnytska;Городницька;Городницкая
UA1808009;UA1808;Dovbyska;Довбиська;Довбышская
UA1808011;UA1808;Dubrivska;Дубрівська;Дубровская
UA1808013;UA1808;Yemilchynska;Ємільчинська;Емильчинская
UA1808015;UA1808;Novohrad-Volynska;Новоград-Волинська;Новоград-Волынская
UA1808017;UA1808;Pishchivska;Піщівська;Пищовская
UA1808019;UA1808;Stryivska;Стриївська;Стриевская
UA1808021;UA1808;Chyzhivska;Чижівська;Чижовская
UA1808023;UA1808;Yarunska;Ярунська;Ярунская
UA2102001;UA2102;Bativska;Батівська;Батьевская
UA2102003;UA2102;Berehivska;Берегівська;Береговская
UA2102005;UA2102;Velykoberezka;Великоберезька;Великобережская
UA2102007;UA2102;Velykobyihanska;Великобийганська;Великобыйганская
UA2102009;UA2102;Vylotska;Вилоцька;Вилокская
UA2102011;UA2102;Vynohradivska;Виноградівська;Виноградовская
UA2102013;UA2102;Kamianska;Кам'янська;Каменская
UA2102015;UA2102;Korolivska;Королівська;Королевская
UA2102017;UA2102;Kosonska;Косоньська;Косоньская
UA2102019;UA2102;Pyiterfolvivska;Пийтерфолвівська;Паятерфолвовский
UA2104001;UA2104;Velykoluchkivska;Великолучківська;Великолучковская
UA2104003;UA2104;Verkhnokoropetska;Верхньокоропецька;Верхнекоропецкая
UA2104005;UA2104;Volovetska;Воловецька;Воловецкая
UA2104007;UA2104;Horondivska;Горондівська;Горондовская
UA2104009;UA2104;Zhdeniivska;Жденіївська;Ждениевская
UA2104011;UA2104;Ivanovetska;Івановецька;Ивановецкая
UA2104013;UA2104;Kolchynska;Кольчинська;Кольчинская
UA2104015;UA2104;Mukachivska;Мукачівська;Мукачевская
UA2104017;UA2104;Nelipynska;Неліпинська;Нелепинская
UA2104019;UA2104;Nyzhnovoritska;Нижньоворітська;Нижневоротская
UA2104021;UA2104;Polianska;Полянська;Полянская
UA2104023;UA2104;Svaliavska;Свалявська;Свалявская
UA2104025;UA2104;Chynadiivska;Чинадіївська;Чинадиевская
UA2106001;UA2106;Bohdanska;Богданська;Богданская
UA2106003;UA2106;Velykobychkivska;Великобичківська;Великобычковская
UA2106005;UA2106;Rakhivska;Рахівська;Раховская
UA2106007;UA2106;Yasinianska;Ясінянська;Ясинянская
UA2108001;UA2108;Bedevlianska;Бедевлянська;Бедевлянская
UA2108003;UA2108;Bushtynska;Буштинська;Буштынская
UA2108005;UA2108;Vilkhovetska;Вільховецька;Ольховецкая
UA2108007;UA2108;Dubivska;Дубівська;Дубовская
UA2108009;UA2108;Neresnytska;Нересницька;Нересницкая
UA2108011;UA2108;Solotvynska;Солотвинська;Солотвинская
UA2108013;UA2108;Teresvianska;Тересвянська;Тересвянская
UA2108015;UA2108;Tiachivska;Тячівська;Тячевская
UA2108017;UA2108;Uhlianska;Углянська;Углянская
UA2108019;UA2108;Ust-Chornianska;Усть-Чорнянська;Усть-Чорнянская
UA2110001;UA2110;Baranynska;Баранинська;Баранинская
UA2110003;UA2110;Velykobereznianska;Великоберезнянська;Великоберезнянская
UA2110005;UA2110;Velykodobronska;Великодобронська;Великодобронская
UA2110007;UA2110;Dubrynytska-Malobereznianska;Дубриницько-Малоберезнянська;Дубриничско-Малоберезнянская
UA2110009;UA2110;Kostrynska;Костринська;Костринская
UA2110011;UA2110;Onokivska;Оноківська;Оноковская
UA2110013;UA2110;Perechynska;Перечинська;Перечинская
UA2110015;UA2110;Serednianska;Середнянська;Среднянская
UA2110017;UA2110;Stavnenska;Ставненська;Ставненская
UA2110019;UA2110;Siurtivska;Сюртівська;Сюртивская
UA2110021;UA2110;Turie-Remetivska;Тур'є-Реметівська;Турье-Реметовская
UA2110023;UA2110;Uzhhorodska;Ужгородська;Ужгородская
UA2110025;UA2110;Kholmkivska;Холмківська;Холмковская
UA2110027;UA2110;Chopska;Чопська;Чопская
UA2112001;UA2112;Bilkivska;Білківська;Белковская
UA2112003;UA2112;Vyshkivska;Вишківська;Вышковская
UA2112005;UA2112;Horinchivska;Горінчівська;Горинчовская
UA2112007;UA2112;Dovzhanska;Довжанська;Должанская
UA2112009;UA2112;Drahivska;Драгівська;Драговская
UA2112011;UA2112;Zarichanska;Зарічанська;Заречанская
UA2112013;UA2112;Irshavska;Іршавська;Иршавская
UA2112015;UA2112;Keretskivska;Керецьківська;Керецковская
UA2112017;UA2112;Kolochavska;Колочавська;Колочавская
UA2112019;UA2112;Mizhhirska;Міжгірська;Межгорская
UA2112021;UA2112;Pylypetska;Пилипецька;Пилипецкая
UA2112023;UA2112;Synevyrska;Синевирська;Синевирская
UA2112025;UA2112;Khustska;Хустська;Хустская
UA2302001;UA2302;Andrivska;Андрівська;Андровская
UA2302003;UA2302;Andriivska;Андріївська;Андреевская
UA2302005;UA2302;Berdianska;Бердянська;Бердянская
UA2302007;UA2302;Berestivska;Берестівська;Берестовская
UA2302009;UA2302;Kolarivska;Коларівська;Коларовская
UA2302011;UA2302;Osypenkivska;Осипенківська;Осипенковская
UA2302013;UA2302;Prymorska;Приморська;Приморская
UA2302015;UA2302;Chernihivska;Чернігівська;Черниговская
UA2304001;UA2304;Blahovishchenska;Благовіщенська;Благовещенская
UA2304003;UA2304;Vasylivska;Василівська;Васильевская
UA2304005;UA2304;Velykobilozerska;Великобілозерська;Великобелозерская
UA2304007;UA2304;Vodianska;Водянська;Водянская
UA2304009;UA2304;Dniprorudnenska;Дніпрорудненська;Днепрорудненская
UA2304011;UA2304;Enerhodarska;Енергодарська;Энергодарская
UA2304013;UA2304;Kamiansko-Dniprovska;Кам'янсько-Дніпровська;Каменско-Днепровская
UA2304015;UA2304;Malobilozerska;Малобілозерська;Малобелозерская
UA2304017;UA2304;Mykhailivska;Михайлівська;Михайловская
UA2304019;UA2304;Rozdolska;Роздольська;Раздольская
UA2304021;UA2304;Stepnohirska;Степногірська;Степногорская
UA2306001;UA2306;Bilenkivska;Біленьківська;Беленьковская
UA2306003;UA2306;Vilnianska;Вільнянська;Вольнянская
UA2306005;UA2306;Dolynska;Долинська;Долинская
UA2306007;UA2306;Zaporizka;Запорізька;Запорожская
UA2306009;UA2306;Komyshuvaska;Комишуваська;Камышевахская
UA2306011;UA2306;Kushuhumska;Кушугумська;Кушугумская
UA2306013;UA2306;Matviivska;Матвіївська;Матвеевская
UA2306015;UA2306;Mykhailivska;Михайлівська;Михайловская
UA2306017;UA2306;Mykhailo-Lukashivska;Михайло-Лукашівська;Михайло-Лукашовская
UA2306019;UA2306;Novomykolaivska;Новомиколаївська;Новониколаевская
UA2306021;UA2306;Novooleksandrivska;Новоолександрівська;Новоалександровская
UA2306023;UA2306;Pavlivska;Павлівська;Павловская
UA2306025;UA2306;Petro-Mykhailivska;Петро-Михайлівська;Петро-Михайловская
UA2306027;UA2306;Stepnenska;Степненська;Степненская
UA2306029;UA2306;Tavriiska;Таврійська;Таврийская
UA2306031;UA2306;Ternuvatska;Тернуватська;Терноватская
UA2306033;UA2306;Shyrokivska;Широківська;Широковская
UA2308001;UA2308;Veselivska;Веселівська;Веселовская
UA2308003;UA2308;Kyrylivska;Кирилівська;Кирилловская
UA2308005;UA2308;Kostiantynivska;Костянтинівська;Константиновская
UA2308007;UA2308;Melitopolska;Мелітопольська;Мелитопольская
UA2308009;UA2308;Myrnenska;Мирненська;Мирненская
UA2308011;UA2308;Novenska;Новенська;Новенская
UA2308013;UA2308;Novobohdanivska;Новобогданівська;Новобогдановская
UA2308015;UA2308;Novovasylivska;Нововасилівська;Нововасилевская
UA2308017;UA2308;Novouspenivska;Новоуспенівська;Новоуспеновская
UA2308019;UA2308;Oleksandrivska;Олександрівська;Александровская
UA2308021;UA2308;Plodorodnenska;Плодородненська;Плодородненская
UA2308023;UA2308;Pryazovska;Приазовська;Приазовская
UA2308025;UA2308;Semenivska;Семенівська;Семеновская
UA2308027;UA2308;Terpinnivska;Терпіннівська;Терпеньевская
UA2308029;UA2308;Chkalovska;Чкаловська;Чкаловская
UA2308031;UA2308;Yakymivska;Якимівська;Акимовская
UA2310001;UA2310;Bilmatska;Більмацька;Бильмакская
UA2310003;UA2310;Vozdvyzhivska;Воздвижівська;Воздвижевская
UA2310005;UA2310;Voskresenska;Воскресенська;Воскресенская
UA2310007;UA2310;Huliaipilska;Гуляйпільська;Гуляйпольская
UA2310009;UA2310;Komysh-Zorianska;Комиш-Зорянська;Камыш-Зарянская
UA2310011;UA2310;Malynivska;Малинівська;Малиновская
UA2310013;UA2310;Malotokmachanska;Малотокмачанська;Малотокмачанская
UA2310015;UA2310;Molochanska;Молочанська;Молочанская
UA2310017;UA2310;Orikhivska;Оріхівська;Ореховская
UA2310019;UA2310;Polohivska;Пологівська;Пологовская
UA2310021;UA2310;Preobrazhenska;Преображенська;Преображенская
UA2310023;UA2310;Rozivska;Розівська;Розовская
UA2310025;UA2310;Smyrnovska;Смирновська;Смирновская
UA2310027;UA2310;Tokmatska;Токмацька;Токмакская
UA2310029;UA2310;Fedorivska;Федорівська;Федоровская
UA2602001;UA2602;Biloberizka;Білоберізька;Белоберезская
UA2602003;UA2602;Verkhovynska;Верховинська;Верховинская
UA2602005;UA2602;Zelenska;Зеленська;Зеленская
UA2604001;UA2604;Bilshivtsivska;Більшівцівська;Большовцовская
UA2604003;UA2604;Bohorodchanska;Богородчанська;Богородчанская
UA2604005;UA2604;Bukachivska;Букачівська;Букачевская
UA2604007;UA2604;Burshtynska;Бурштинська;Бурштынская
UA2604009;UA2604;Halytska;Галицька;Галичская
UA2604011;UA2604;Dzvyniatska;Дзвиняцька;Дзвинячская
UA2604013;UA2604;Dubovetska;Дубовецька;Дубовецкая
UA2604015;UA2604;Yezupilska;Єзупільська;Езупильская
UA2604017;UA2604;Zahvizdianska;Загвіздянська;Загвоздянская
UA2604019;UA2604;Ivano-Frankivska;Івано-Франківська;Ивано-Франковская
UA2604021;UA2604;Lysetska;Лисецька;Лисецкая
UA2604023;UA2604;Obertynska;Обертинська;Обертинская
UA2604025;UA2604;Oleshanska;Олешанська;Олешанская
UA2604027;UA2604;Rohatynska;Рогатинська;Рогатинская
UA2604029;UA2604;Solotvynska;Солотвинська;Солотвинская
UA2604031;UA2604;Starobohorodchanska;Старобогородчанська;Старобогородчанская
UA2604033;UA2604;Tysmenytska;Тисменицька;Тысменицкая
UA2604035;UA2604;Tlumatska;Тлумацька;Тлумачская
UA2604037;UA2604;Uhrynivska;Угринівська;Угриновская
UA2604039;UA2604;Yamnytska;Ямницька;Ямницкая
UA2606001;UA2606;Bolekhivska;Болехівська;Болеховская
UA2606003;UA2606;Broshniv-Osadska;Брошнів-Осадська;Брошнев-Осадская
UA2606005;UA2606;Verkhnianska;Верхнянська;Верхнянская
UA2606007;UA2606;Vyhodska;Вигодська;Выгодская
UA2606009;UA2606;Vytvytska;Витвицька;Витвицкая
UA2606011;UA2606;Voinylivska;Войнилівська;Войниловская
UA2606013;UA2606;Dolynska;Долинська;Долинская
UA2606015;UA2606;Dubivska;Дубівська;Дубовская
UA2606017;UA2606;Kaluska;Калуська;Калушская
UA2606019;UA2606;Novytska;Новицька;Новицкая
UA2606021;UA2606;Perehinska;Перегінська;Перегинская
UA2606023;UA2606;Rozhniativska;Рожнятівська;Рожнятовская
UA2606025;UA2606;Spaska;Спаська;Спасская
UA2608001;UA2608;Hvizdetska;Гвіздецька;Гвоздецкая
UA2608003;UA2608;Horodenkivska;Городенківська;Городенковская
UA2608005;UA2608;Zabolotivska;Заболотівська;Заболотовская
UA2608007;UA2608;Kolomyiska;Коломийська;Коломыйская
UA2608009;UA2608;Korshivska;Коршівська;Коршевская
UA2608011;UA2608;Mateievetska;Матеївецька;Матеевецкая
UA2608013;UA2608;Nyzhnoverbizka;Нижньовербізька;Нижневербижская
UA2608015;UA2608;Otyniiska;Отинійська;Отынийская
UA2608017;UA2608;Pechenizhynska;Печеніжинська;Печиніжинская
UA2608019;UA2608;Pidhaichykivska;Підгайчиківська;Подгайчиковская
UA2608021;UA2608;Piadytska;П'ядицька;Пядикская
UA2608023;UA2608;Sniatynska;Снятинська;Снятынская
UA2608025;UA2608;Chernelytska;Чернелицька;Чернелицкая
UA2610001;UA2610;Kosivska;Косівська;Косовская
UA2610003;UA2610;Kosmatska;Космацька;Космачская
UA2610005;UA2610;Kutska;Кутська;Кутская
UA2610007;UA2610;Rozhnivska;Рожнівська;Рожновская
UA2610009;UA2610;Yablunivska;Яблунівська;Яблоновская
UA2612001;UA2612;Vorokhtianska;Ворохтянська;Ворохтянская
UA2612003;UA2612;Deliatynska;Делятинська;Делятинская
UA2612005;UA2612;Lanchynska;Ланчинська;Ланчинская
UA2612007;UA2612;Nadvirnianska;Надвірнянська;Надворнянская
UA2612009;UA2612;Pasichnianska;Пасічнянська;Пасечнянская
UA2612011;UA2612;Pererislianska;Переріслянська;Перерослянская
UA2612013;UA2612;Polianytska;Поляницька;Поляницкая
UA2612015;UA2612;Yaremchanska;Яремчанська;Яремчанская
UA3200000;UA3200;Chornobylska zona vidchuzhennia;Чорнобильська зона відчуження;Чернобыльская зона отчуждения
UA3202001;UA3202;Bilotserkivska;Білоцерківська;Белоцерковская
UA3202003;UA3202;Volodarska;Володарська;Володарская
UA3202005;UA3202;Hrebinkivska;Гребінківська;Гребенковская
UA3202007;UA3202;Kovalivska;Ковалівська;Ковалевская
UA3202009;UA3202;Malovilshanska;Маловільшанська;Малоольшанская
UA3202011;UA3202;Medvynska;Медвинська;Медвинская
UA3202013;UA3202;Rokytnianska;Рокитнянська;Ракитнянская
UA3202015;UA3202;Skvyrska;Сквирська;Сквирская
UA3202017;UA3202;Stavyshchenska;Ставищенська;Ставищенская
UA3202019;UA3202;Tarashchanska;Таращанська;Таращанская
UA3202021;UA3202;Tetiivska;Тетіївська;Тетиевская
UA3202023;UA3202;Uzynska;Узинська;Узинская
UA3202025;UA3202;Fursivska;Фурсівська;Фурсовская
UA3204001;UA3204;Boryspilska;Бориспільська;Бориспольская
UA3204003;UA3204;Voronkivska;Вороньківська;Воронковская
UA3204005;UA3204;Hirska;Гірська;Горская
UA3204007;UA3204;Divychkivska;Дівичківська;Девичковская
UA3204009;UA3204;Zolochivska;Золочівська;Золочевская
UA3204011;UA3204;Pereiaslavсska;Переяславська;Переяславская
UA3204013;UA3204;Prystolychna;Пристолична;Пристоличная
UA3204015;UA3204;Studenykivska;Студениківська;Студениковская
UA3204017;UA3204;Tashanska;Ташанська;Ташанская
UA3204019;UA3204;Tsyblivska;Циблівська;Цибливская
UA3204021;UA3204;Yahotynska;Яготинська;Яготинская
UA3206001;UA3206;Baryshivska;Баришівська;Барышевская
UA3206003;UA3206;Berezanska;Березанська;Березанская
UA3206005;UA3206;Brovarska;Броварська;Броварская
UA3206007;UA3206;Velykodymerska;Великодимерська;Великодымерская
UA3206009;UA3206;Zazymska;Зазимська;Зазимская
UA3206011;UA3206;Zghurivska;Згурівська;Згуровская
UA3206013;UA3206;Kalynivska;Калинівська;Калиновская
UA3206015;UA3206;Kalytianska;Калитянська;Калитянская
UA3208001;UA3208;Bilohorodska;Білогородська;Белогородская
UA3208003;UA3208;Borodianska;Бородянська;Бородянская
UA3208005;UA3208;Borshchahivska;Борщагівська;Борщаговская
UA3208007;UA3208;Buchanska;Бучанська;Бучанская
UA3208009;UA3208;Vyshneva;Вишнева;Вишневая
UA3208011;UA3208;Hostomelska;Гостомельська;Гостомельская
UA3208013;UA3208;Dmytrivska;Дмитрівська;Дмитровская
UA3208015;UA3208;Irpinska;Ірпінська;Ирпенская
UA3208017;UA3208;Kotsiubynska;Коцюбинська;Коцюбинская
UA3208019;UA3208;Makarivska;Макарівська;Макаровская
UA3208021;UA3208;Nemishaivska;Немішаївська;Немешаевская
UA3208023;UA3208;Piskivska;Пісківська;Песковская
UA3210001;UA3210;Vyshhorodska;Вишгородська;Вышгородская
UA3210003;UA3210;Dymerska;Димерська;Дымерская
UA3210005;UA3210;Ivankivska;Іванківська;Иванковская
UA3210007;UA3210;Petrivska;Петрівська;Петровская
UA3210009;UA3210;Pirnivska;Пірнівська;Пирновская
UA3210011;UA3210;Poliska;Поліська;Полесская
UA3210013;UA3210;Slavutytska;Славутицька;Славутичская
UA3212001;UA3212;Bohuslavska;Богуславська;Богуславская
UA3212003;UA3212;Vasylkivska;Васильківська;Васильковская
UA3212005;UA3212;Kaharlytska;Кагарлицька;Кагарлыкская
UA3212007;UA3212;Kozynska;Козинська;Козинская
UA3212009;UA3212;Myronivska;Миронівська;Мироновская
UA3212011;UA3212;Obukhivska;Обухівська;Обуховская
UA3212013;UA3212;Rzhyshchivska;Ржищівська;Ржищевская
UA3212015;UA3212;Ukrainska;Українська;Украинская
UA3212017;UA3212;Feodosiivska;Феодосіївська;Феодосиевская
UA3214001;UA3214;Byshivska;Бишівська;Бышевская
UA3214003;UA3214;Boiarska;Боярська;Боярская
UA3214005;UA3214;Hatnenska;Гатненська;Гатненская
UA3214007;UA3214;Hlevakhivska;Глевахівська;Глеваховская
UA3214009;UA3214;Kalynivska;Калинівська;Калиновская
UA3214011;UA3214;Kozhanska;Кожанська;Кожанская
UA3214013;UA3214;Tomashivska;Томашівська;Томашовская
UA3214015;UA3214;Fastivska;Фастівська;Фастовская
UA3214017;UA3214;Chabanivska;Чабанівська;Чабановская
UA3502001;UA3502;Blahovishchenska;Благовіщенська;Благовещенская
UA3502003;UA3502;Vilshanska;Вільшанська;Ольшанская
UA3502005;UA3502;Haivoronska;Гайворонська;Гайворонская
UA3502007;UA3502;Holovanivska;Голованівська;Голованевская
UA3502009;UA3502;Zavallivska;Заваллівська;Завальевская
UA3502011;UA3502;Nadlatska;Надлацька;Надлакская
UA3502013;UA3502;Novoarkhanhelska;Новоархангельська;Новоархангельская
UA3502015;UA3502;Perehonivska;Перегонівська;Перегоновская
UA3502017;UA3502;Pidvysotska;Підвисоцька;Подвысоцкая
UA3502019;UA3502;Pobuzka;Побузька;Побугская
UA3504001;UA3504;Adzhamska;Аджамська;Аджамская
UA3504003;UA3504;Bobrynetska;Бобринецька;Бобринецкая
UA3504005;UA3504;Velykoseverynivska;Великосеверинівська;Великосевериновская
UA3504007;UA3504;Hurivska;Гурівська;Гуровская
UA3504009;UA3504;Dmytrivska;Дмитрівська;Дмитровская
UA3504011;UA3504;Dolynska;Долинська;Долинская
UA3504013;UA3504;Znamianska;Знам'янська;Знаменская
UA3504015;UA3504;Katerynivska;Катеринівська;Катериновская
UA3504017;UA3504;Ketrysanivska;Кетрисанівська;Кетрисановская
UA3504019;UA3504;Kompaniivska;Компаніївська;Компанеевская
UA3504021;UA3504;Kropyvnytskyi;Кропивницька;Кропивницкая
UA3504023;UA3504;Novhorodkivska;Новгородківська;Новгородковская
UA3504025;UA3504;Oleksandrivska;Олександрівська;Александровская
UA3504027;UA3504;Pervozvanivska;Первозванівська;Первозвановская
UA3504029;UA3504;Sokolivska;Соколівська;Соколовская
UA3504031;UA3504;Subottsivska;Суботцівська;Субботцевская
UA3504033;UA3504;Ustynivska;Устинівська;Устиновская
UA3506001;UA3506;Hannivska;Ганнівська;Анновская
UA3506003;UA3506;Hlodoska;Глодоська;Глодосская
UA3506005;UA3506;Dobrovelychkivska;Добровеличківська;Добровеличковская
UA3506007;UA3506;Zlynska;Злинська;Злынская
UA3506009;UA3506;Malovyskivska;Маловисківська;Маловисковская
UA3506011;UA3506;Marianivska;Мар'янівська;Марьяновская
UA3506013;UA3506;Novomyrhorodska;Новомиргородська;Новомиргородская
UA3506015;UA3506;Novoukrainska;Новоукраїнська;Новоукраинская
UA3506017;UA3506;Pishchanobridska;Піщанобрідська;Песчанобродская
UA3506019;UA3506;Pomichnianska;Помічнянська;Помошнянская
UA3506021;UA3506;Rivnianska;Рівнянська;Ровнянская
UA3506023;UA3506;Smolinska;Смолінська;Смолинская
UA3506025;UA3506;Tyshkivska;Тишківська;Тишковская
UA3508001;UA3508;Velykoandrusivska;Великоандрусівська;Великоандрусовская
UA3508003;UA3508;Novoprazka;Новопразька;Новопражская
UA3508005;UA3508;Oleksandriiska;Олександрійська;Александрийская
UA3508007;UA3508;Onufriivska;Онуфріївська;Онуфриевская
UA3508009;UA3508;Pantaivska;Пантаївська;Пантаевская
UA3508011;UA3508;Petrivska;Петрівська;Петровская
UA3508013;UA3508;Popelnastivska;Попельнастівська;Попельнастовская
UA3508015;UA3508;Pryiutivska;Приютівська;Приютовская
UA3508017;UA3508;Svitlovodska;Світловодська;Светловодская
UA4402001;UA4402;Alchevska;Алчевська;Алчевская
UA4402003;UA4402;Zymohirivska;Зимогір'ївська;Зимогорьевская
UA4402005;UA4402;Kadiivska;Кадіївська;Кадиевская
UA4404001;UA4404;Dovzhanska;Довжанська;Должанская
UA4404003;UA4404;Sorokynska;Сорокинська;Сорокинская
UA4406001;UA4406;Luhanska;Луганська;Луганская
UA4406003;UA4406;Lutuhynska;Лутугинська;Лутугинская
UA4406005;UA4406;Molodohvardiiska;Молодогвардійська;Молодогвардейская
UA4408001;UA4408;Antratsytivska;Антрацитівська;Антрацитовская
UA4408003;UA4408;Rovenkivska;Ровеньківська;Ровеньковская
UA4408005;UA4408;Khrustalnenska;Хрустальненська;Хрустальненская
UA4410001;UA4410;Bilokurakynska;Білокуракинська;Белокуракинская
UA4410003;UA4410;Kolomyichyska;Коломийчиська;Коломыйчихская
UA4410005;UA4410;Krasnorichenska;Красноріченська;Краснореченская
UA4410007;UA4410;Lozno-Oleksandrivska;Лозно-Олександрівська;Лозно-Александровская
UA4410009;UA4410;Nyzhnoduvanska;Нижньодуванська;Нижнедуванская
UA4410011;UA4410;Svativska;Сватівська;Сватовская
UA4410013;UA4410;Troitska;Троїцька;Троицкая
UA4412001;UA4412;Hirska;Гірська;Горская
UA4412003;UA4412;Kreminska;Кремінська;Кременская
UA4412005;UA4412;Lysychanska;Лисичанська;Лисичанская
UA4412007;UA4412;Popasnianska;Попаснянська;Попаснянская
UA4412009;UA4412;Rubizhanska;Рубіжанська;Рубежанская
UA4412011;UA4412;Sievierodonetska;Сєвєродонецька;Северодонецкая
UA4414001;UA4414;Bilovodska;Біловодська;Беловодская
UA4414003;UA4414;Bilolutska;Білолуцька;Белолуцкая
UA4414005;UA4414;Markivska;Марківська;Марковская
UA4414007;UA4414;Milovska;Міловська;Меловская
UA4414009;UA4414;Novopskovska;Новопсковська;Новопсковская
UA4414011;UA4414;Starobilska;Старобільська;Старобельская
UA4414013;UA4414;Chmyrivska;Чмирівська;Чмыровская
UA4414015;UA4414;Shulhynska;Шульгинська;Шульгинская
UA4416001;UA4416;Nyzhnoteplivska;Нижньотеплівська;Нижнетепловская
UA4416003;UA4416;Novoaidarska;Новоайдарська;Новоайдарская
UA4416005;UA4416;Stanychno-Luhanska;Станично-Луганська;Станично-Луганская
UA4416007;UA4416;Shyrokivska;Широківська;Широковская
UA4416009;UA4416;Shchastynska;Щастинська;Счастьенская
UA4602001;UA4602;Boryslavska;Бориславська;Бориславская
UA4602003;UA4602;Drohobytska;Дрогобицька;Дрогобычская
UA4602005;UA4602;Medenytska;Меденицька;Меденичская
UA4602007;UA4602;Skhidnytska;Східницька;Сходницкая
UA4602009;UA4602;Truskavetska;Трускавецька;Трускавецкая
UA4604001;UA4604;Brodivska;Бродівська;Бродовская
UA4604003;UA4604;Buska;Буська;Бусская
UA4604005;UA4604;Zabolottsivska;Заболотцівська;Заболотцевская
UA4604007;UA4604;Zolochivska;Золочівська;Золочевская
UA4604009;UA4604;Krasnenska;Красненська;Красненская
UA4604011;UA4604;Pidkaminska;Підкамінська;Подкаменская
UA4604013;UA4604;Pomorianska;Поморянська;Поморянская
UA4606001;UA4606;Bibrska;Бібрська;Бобркская
UA4606003;UA4606;Velykoliubinska;Великолюбінська;Великолюбенская
UA4606005;UA4606;Hlynianska;Глинянська;Глинянская
UA4606007;UA4606;Horodotska;Городоцька;Городокская
UA4606009;UA4606;Davydivska;Давидівська;Давыдовская
UA4606011;UA4606;Dobrosynsko-Maherivska;Добросинсько-Магерівська;Добросинско-Магеровская
UA4606013;UA4606;Zhovkivska;Жовківська;Жолковская
UA4606015;UA4606;Zhovtanetska;Жовтанецька;Жовтанецкая
UA4606017;UA4606;Zymnovodivska;Зимноводівська;Зимноводовская
UA4606019;UA4606;Kamianka-Buzka;Кам'янка-Бузька;Каменка-Бугская
UA4606021;UA4606;Komarnivska;Комарнівська;Комарновская
UA4606023;UA4606;Kulykivska;Куликівська;Куликовская
UA4606025;UA4606;Lvivska;Львівська;Львовская
UA4606027;UA4606;Murovanska;Мурованська;Мурованская
UA4606029;UA4606;Novoiarychivska;Новояричівська;Новоярычевская
UA4606031;UA4606;Obroshynska;Оброшинська;Оброшинская
UA4606033;UA4606;Peremyshlianska;Перемишлянська;Перемышлянская
UA4606035;UA4606;Pidberiztsivska;Підберізцівська;Подберезцевская
UA4606037;UA4606;Pustomytivska;Пустомитівська;Пустомытовская
UA4606039;UA4606;Rava-Ruska;Рава-Руська;Рава-Русская
UA4606041;UA4606;Sokilnytska;Сокільницька;Сокольникская
UA4606043;UA4606;Solonkivska;Солонківська;Солонковская
UA4606045;UA4606;Shchyretska;Щирецька;Щирецкая
UA4608001;UA4608;Biskovytska;Бісковицька;Бисковичская
UA4608003;UA4608;Borynska;Боринська;Борынская
UA4608005;UA4608;Dobromylska;Добромильська;Добромильская
UA4608007;UA4608;Novokalynivska;Новокалинівська;Новокалиновская
UA4608009;UA4608;Ralivska;Ралівська;Ралевская
UA4608011;UA4608;Rudkivska;Рудківська;Рудковская
UA4608013;UA4608;Sambirska;Самбірська;Самборская
UA4608015;UA4608;Starosambirska;Старосамбірська;Старосамборская
UA4608017;UA4608;Strilkivska;Стрілківська;Стрелковская
UA4608019;UA4608;Turkivska;Турківська;Турковская
UA4608021;UA4608;Khyrivska;Хирівська;Хыровская
UA4610001;UA4610;Hnizdychivska;Гніздичівська;Гнездычевская
UA4610003;UA4610;Hrabovetsko-Dulibivska;Грабовецько-Дулібівська;Грабовецко-Дулибовская
UA4610005;UA4610;Zhydachivska;Жидачівська;Жидачовская
UA4610007;UA4610;Zhuravnenska;Журавненська;Журавненская
UA4610009;UA4610;Kozivska;Козівська;Козевская
UA4610011;UA4610;Mykolaivska;Миколаївська;Николаевская
UA4610013;UA4610;Morshynska;Моршинська;Моршинская
UA4610015;UA4610;Novorozdilska;Новороздільська;Новороздольская
UA4610017;UA4610;Rozvadivska;Розвадівська;Розвадовская
UA4610019;UA4610;Skolivska;Сколівська;Сколевская
UA4610021;UA4610;Slavska;Славська;Славская
UA4610023;UA4610;Stryiska;Стрийська;Стрыйская
UA4610025;UA4610;Trostianetska;Тростянецька;Тростянецкая
UA4610027;UA4610;Khodorivska;Ходорівська;Ходоровская
UA4612001;UA4612;Belzka;Белзька;Белзская
UA4612003;UA4612;Velykomostivska;Великомостівська;Великомостовская
UA4612005;UA4612;Dobrotvirska;Добротвірська;Добротворская
UA4612007;UA4612;Lopatynska;Лопатинська;Лопатинская
UA4612009;UA4612;Radekhivska;Радехівська;Радеховская
UA4612011;UA4612;Sokalska;Сокальська;Сокальская
UA4612013;UA4612;Chervonohradska;Червоноградська;Червоноградская
UA4614001;UA4614;Ivano-Frankivska;Івано-Франківська;Ивано-Франковская
UA4614003;UA4614;Mostyska;Мостиська;Мостисская
UA4614005;UA4614;Novoiavorivska;Новояворівська;Новояворовская
UA4614007;UA4614;Sudovovyshnianska;Судововишнянська;Судововишнянская
UA4614009;UA4614;Shehynivska;Шегинівська;Шегиновская
UA4614011;UA4614;Yavorivska;Яворівська;Яворовская
UA4802001;UA4802;Bashtanska;Баштанська;Баштанская
UA4802003;UA4802;Bereznehuvatska;Березнегуватська;Березнеговатская
UA4802005;UA4802;Vilnozaporizka;Вільнозапорізька;Вольнозапорожская
UA4802007;UA4802;Volodymyrivska;Володимирівська;Владимировская
UA4802009;UA4802;Horokhivska;Горохівська;Гороховская
UA4802011;UA4802;Inhulska;Інгульська;Ингульская
UA4802013;UA4802;Kazankivska;Казанківська;Казанковская
UA4802015;UA4802;Novobuzka;Новобузька;Новобугская
UA4802017;UA4802;Pryvilnenska;Привільненська;Привольненская
UA4802019;UA4802;Snihurivska;Снігурівська;Снигиревская
UA4802021;UA4802;Sofiivska;Софіївська;Софиевская
UA4802023;UA4802;Shyrokivska;Широківська;Широковская
UA4804001;UA4804;Bratska;Братська;Братская
UA4804003;UA4804;Buzka;Бузька;Бугская
UA4804005;UA4804;Veselynivska;Веселинівська;Веселиновская
UA4804007;UA4804;Voznesenska;Вознесенська;Вознесенская
UA4804009;UA4804;Domanivska;Доманівська;Доманевская
UA4804011;UA4804;Doroshivska;Дорошівська;Дорошовская
UA4804013;UA4804;Yelanetska;Єланецька;Еланецкая
UA4804015;UA4804;Mostivska;Мостівська;Мостовская
UA4804017;UA4804;Novomarivska;Новомар'ївська;Новомарьевская
UA4804019;UA4804;Oleksandrivska;Олександрівська;Александровская
UA4804021;UA4804;Prybuzhanivska;Прибужанівська;Прибужановская
UA4804023;UA4804;Prybuzka;Прибузька;Прибужская
UA4804025;UA4804;Yuzhnoukrainska;Южноукраїнська;Южноукраинская
UA4806001;UA4806;Berezanska;Березанська;Березанская
UA4806003;UA4806;Vesnianska;Веснянська;Веснянская
UA4806005;UA4806;Voskresenska;Воскресенська;Воскресенская
UA4806007;UA4806;Halytsynivska;Галицинівська;Галицыновская
UA4806009;UA4806;Koblivska;Коблівська;Коблевская
UA4806011;UA4806;Kostiantynivska;Костянтинівська;Константиновская
UA4806013;UA4806;Kutsurubska;Куцурубська;Куцурубская
UA4806015;UA4806;Mykolaivska;Миколаївська;Николаевская
UA4806017;UA4806;Mishkovo-Pohorilivska;Мішково-Погорілівська;Мешково-Погореловская
UA4806019;UA4806;Nechaianska;Нечаянська;Нечаянская
UA4806021;UA4806;Novoodeska;Новоодеська;Новоодесская
UA4806023;UA4806;Olshanska;Ольшанська;Ольшанская
UA4806025;UA4806;Ochakivska;Очаківська;Очаковская
UA4806027;UA4806;Pervomaiska;Первомайська;Первомайская
UA4806029;UA4806;Radsadivska;Радсадівська;Радсадовская
UA4806031;UA4806;Stepivska;Степівська;Степовская
UA4806033;UA4806;Sukhoielanetska;Сухоєланецька;Сухоеланецкая
UA4806035;UA4806;Chornomorska;Чорноморська;Черноморская
UA4806037;UA4806;Shevchenkivska;Шевченківська;Шевченковская
UA4808001;UA4808;Arbuzynska;Арбузинська;Арбузинская
UA4808003;UA4808;Blahodatnenska;Благодатненська;Благодатненская
UA4808005;UA4808;Vradiivska;Врадіївська;Врадиевская
UA4808007;UA4808;Kamianomostivska;Кам'яномостівська;Каменномостовская
UA4808009;UA4808;Kryvoozerska;Кривоозерська;Кривоозерская
UA4808011;UA4808;Myhiivska;Мигіївська;Мигиевская
UA4808013;UA4808;Pervomaiska;Первомайська;Первомайская
UA4808015;UA4808;Syniukhynobridska;Синюхинобрідська;Синюхинобродская
UA5102001;UA5102;Andriievo-Ivanivska;Андрієво-Іванівська;Андреево-Ивановская
UA5102003;UA5102;Berezivska;Березівська;Березовская
UA5102005;UA5102;Velykobuialytska;Великобуялицька;Великобуялицкая
UA5102007;UA5102;Znamianska;Знам'янська;Знаменская
UA5102009;UA5102;Ivanivska;Іванівська;Ивановская
UA5102011;UA5102;Konoplianska;Коноплянська;Коноплянская
UA5102013;UA5102;Kurisovska;Курісовська;Курисовская
UA5102015;UA5102;Mykolaivska;Миколаївська;Николаевская
UA5102017;UA5102;Novokalchevska;Новокальчевська;Новокальчевская
UA5102019;UA5102;Petrovirivska;Петровірівська;Петроверовская
UA5102021;UA5102;Raukhivska;Раухівська;Рауховская
UA5102023;UA5102;Rozkvitivska;Розквітівська;Розквитовская
UA5102025;UA5102;Staromaiakivska;Старомаяківська;Старомаяковская
UA5102027;UA5102;Striukivska;Стрюківська;Стрюковская
UA5102029;UA5102;Chohodarivska;Чогодарівська;Чегодаровская
UA5102031;UA5102;Shyriaivska;Ширяївська;Ширяевская
UA5104001;UA5104;Bilhorod-Dnistrovska;Білгород-Дністровська;Белгород-Днестровская
UA5104003;UA5104;Dyviziiska;Дивізійська;Дивизийская
UA5104005;UA5104;Karolino-Buhazka;Кароліно-Бугазька;Каролино-Бугазская
UA5104007;UA5104;Kulevchanska;Кулевчанська;Кулевчанская
UA5104009;UA5104;Lymanska;Лиманська;Лиманская
UA5104011;UA5104;Marazliivska;Маразліївська;Маразлиевская
UA5104013;UA5104;Molohivska;Мологівська;Мологовская
UA5104015;UA5104;Petropavlivska;Петропавлівська;Петропавловская
UA5104017;UA5104;Plakhtiivska;Плахтіївська;Плахтиевская
UA5104019;UA5104;Saratska;Саратська;Саратская
UA5104021;UA5104;Serhiivska;Сергіївська;Сергеевская
UA5104023;UA5104;Starokozatska;Старокозацька;Староказацкая
UA5104025;UA5104;Tatarbunarska;Татарбунарська;Татарбунарская
UA5104027;UA5104;Tuzlivska;Тузлівська;Тузловская
UA5104029;UA5104;Uspenivska;Успенівська;Успеновская
UA5104031;UA5104;Shabivska;Шабівська;Шабовская
UA5106001;UA5106;Artsyzka;Арцизька;Арцизская
UA5106003;UA5106;Bolhradska;Болградська;Болградская
UA5106005;UA5106;Borodinska;Бородінська;Бородинская
UA5106007;UA5106;Vasylivska;Василівська;Василевская
UA5106009;UA5106;Horodnenska;Городненська;Городненская
UA5106011;UA5106;Krynychnenska;Криничненська;Крынычненская
UA5106013;UA5106;Kubeiska;Кубейська;Кубейская
UA5106015;UA5106;Pavlivska;Павлівська;Павловская
UA5106017;UA5106;Tarutynska;Тарутинська;Тарутинская
UA5106019;UA5106;Teplytska;Теплицька;Теплицкая
UA5108001;UA5108;Vylkivska;Вилківська;Вилковская
UA5108003;UA5108;Izmailska;Ізмаїльська;Измаильская
UA5108005;UA5108;Kiliiska;Кілійська;Килийская
UA5108007;UA5108;Reniiska;Ренійська;Ренийская
UA5108009;UA5108;Safianivska;Саф'янівська;Сафьяновская
UA5108011;UA5108;Suvorovska;Суворовська;Суворовская
UA5110001;UA5110;Avanhardivska;Авангардівська;Авангардская
UA5110003;UA5110;Biliaivska;Біляївська;Беляевская
UA5110005;UA5110;Velykodalnytska;Великодальницька;Великодальникская
UA5110007;UA5110;Velykodolynska;Великодолинська;Великодолинская
UA5110009;UA5110;Vyhodianska;Вигодянська;Выгодянская
UA5110011;UA5110;Vyzyrska;Визирська;Визирская
UA5110013;UA5110;Dalnytska;Дальницька;Дальникская
UA5110015;UA5110;Dachnenska;Дачненська;Дачненская
UA5110017;UA5110;Dobroslavska;Доброславська;Доброславская
UA5110019;UA5110;Krasnosilska;Красносільська;Красносельская
UA5110021;UA5110;Maiakivska;Маяківська;Маяковская
UA5110023;UA5110;Nerubaiska;Нерубайська;Нерубайская
UA5110025;UA5110;Ovidiopolska;Овідіопольська;Овидиопольская
UA5110027;UA5110;Odeska;Одеська;Одесская
UA5110029;UA5110;Tairovska;Таїровська;Таировская
UA5110031;UA5110;Teplodarska;Теплодарська;Теплодарская
UA5110033;UA5110;Usativska;Усатівська;Усатовская
UA5110035;UA5110;Fontanska;Фонтанська;Фонтанская
UA5110037;UA5110;Chornomorska;Чорноморська;Черноморская
UA5110039;UA5110;Chornomorska;Чорноморська;Черноморская
UA5110041;UA5110;Yuzhnenska;Южненська;Южненская
UA5110043;UA5110;Yaskivska;Яськівська;Яськовская
UA5112001;UA5112;Ananivska;Ананьївська;Ананьевская
UA5112003;UA5112;Baltska;Балтська;Балтская
UA5112005;UA5112;Dolynska;Долинська;Долинская
UA5112007;UA5112;Zelenohirska;Зеленогірська;Зеленогорская
UA5112009;UA5112;Kodymska;Кодимська;Кодымская
UA5112011;UA5112;Kuialnytska;Куяльницька;Куяльникская
UA5112013;UA5112;Liubashivska;Любашівська;Любашевская
UA5112015;UA5112;Oknianska;Окнянська;Окнянская
UA5112017;UA5112;Pishchanska;Піщанська;Песчанская
UA5112019;UA5112;Podilska;Подільська;Подольская
UA5112021;UA5112;Savranska;Савранська;Савранская
UA5112023;UA5112;Slobidska;Слобідська;Слободская
UA5114001;UA5114;Velykomykhailivska;Великомихайлівська;Великомихайловская
UA5114003;UA5114;Velykoploskivska;Великоплосківська;Великоплосковская
UA5114005;UA5114;Zatyshanska;Затишанська;Затишанская
UA5114007;UA5114;Zakharivska;Захарівська;Захаровская
UA5114009;UA5114;Lymanska;Лиманська;Лиманская
UA5114011;UA5114;Novoborysivska;Новоборисівська;Новоборисовская
UA5114013;UA5114;Rozdilnianska;Роздільнянська;Раздельнянская
UA5114015;UA5114;Stepanivska;Степанівська;Степановская
UA5114017;UA5114;Tsebrykivska;Цебриківська;Цебриковская
UA5302001;UA5302;Hlobynska;Глобинська;Глобинская
UA5302003;UA5302;Horishnoplavnivska;Горішньоплавнівська;Горишнеплавневская
UA5302005;UA5302;Hradyzka;Градизька;Градижская
UA5302007;UA5302;Kamianopotokivska;Кам'янопотоківська;Каменнопотоковская
UA5302009;UA5302;Kozelshchynska;Козельщинська;Козельщинская
UA5302011;UA5302;Kremenchutska;Кременчуцька;Кременчугская
UA5302013;UA5302;Novohaleshchynska;Новогалещинська;Новогалещинская
UA5302015;UA5302;Obolonska;Оболонська;Оболонская
UA5302017;UA5302;Omelnytska;Омельницька;Омельникская
UA5302019;UA5302;Pishchanska;Піщанська;Песчанская
UA5302021;UA5302;Pryshybska;Пришибська;Пришибская
UA5302023;UA5302;Semenivska;Семенівська;Семеновская
UA5304001;UA5304;Hrebinkivska;Гребінківська;Гребенковская
UA5304003;UA5304;Lubenska;Лубенська;Лубенская
UA5304005;UA5304;Novoorzhytska;Новооржицька;Новооржицкая
UA5304007;UA5304;Orzhytska;Оржицька;Оржицкая
UA5304009;UA5304;Pyriatynska;Пирятинська;Пирятинская
UA5304011;UA5304;Khorolska;Хорольська;Хорольская
UA5304013;UA5304;Chornukhynska;Чорнухинська;Чернухинская
UA5306001;UA5306;Bilotserkivska;Білоцерківська;Белоцерковская
UA5306003;UA5306;Velykobahachanska;Великобагачанська;Великобагачанская
UA5306005;UA5306;Velykobudyshchanska;Великобудищанська;Великобудищанская
UA5306007;UA5306;Velykosorochynska;Великосорочинська;Великосорочинская
UA5306009;UA5306;Hadiatska;Гадяцька;Гадячская
UA5306011;UA5306;Hoholivska;Гоголівська;Гоголевская
UA5306013;UA5306;Zavodska;Заводська;Заводская
UA5306015;UA5306;Komyshnianska;Комишнянська;Камышнянская
UA5306017;UA5306;Krasnolutska;Краснолуцька;Краснолукская
UA5306019;UA5306;Lokhvytska;Лохвицька;Лохвицкая
UA5306021;UA5306;Liutenska;Лютенська;Лютенская
UA5306023;UA5306;Myrhorodska;Миргородська;Миргородская
UA5306025;UA5306;Petrivsko-Romenska;Петрівсько-Роменська;Петровско-Роменская
UA5306027;UA5306;Romodanivska;Ромоданівська;Ромодановская
UA5306029;UA5306;Senchanska;Сенчанська;Сенчанская
UA5306031;UA5306;Serhiivska;Сергіївська;Сергеевская
UA5306033;UA5306;Shyshatska;Шишацька;Шишацкая
UA5308001;UA5308;Bilytska;Білицька;Беликская
UA5308003;UA5308;Velykorublivska;Великорублівська;Великорублевская
UA5308005;UA5308;Dykanska;Диканська;Диканьская
UA5308007;UA5308;Drabynivska;Драбинівська;Драбиновская
UA5308009;UA5308;Zinkivska;Зіньківська;Зеньковская
UA5308011;UA5308;Karlivska;Карлівська;Карловская
UA5308013;UA5308;Kobeliatska;Кобеляцька;Кобелякская
UA5308015;UA5308;Kolomatska;Коломацька;Коломакская
UA5308017;UA5308;Kotelevska;Котелевська;Котелевская
UA5308019;UA5308;Lannivska;Ланнівська;Ланновская
UA5308021;UA5308;Martynivska;Мартинівська;Мартыновская
UA5308023;UA5308;Machukhivska;Мачухівська;Мачеховская
UA5308025;UA5308;Mashivska;Машівська;Машевская
UA5308027;UA5308;Mykhailivska;Михайлівська;Михайловская
UA5308029;UA5308;Nekhvoroshchanska;Нехворощанська;Нехворощанская
UA5308031;UA5308;Novosanzharska;Новосанжарська;Новосанжарская
UA5308033;UA5308;Novoselivska;Новоселівська;Новоселовская
UA5308035;UA5308;Opishnianska;Опішнянська;Опошнянская
UA5308037;UA5308;Poltavska;Полтавська;Полтавская
UA5308039;UA5308;Reshetylivska;Решетилівська;Решетиловская
UA5308041;UA5308;Skorokhodivska;Скороходівська;Скороходовская
UA5308043;UA5308;Tereshkivska;Терешківська;Терешковская
UA5308045;UA5308;Chutivska;Чутівська;Чутовская
UA5308047;UA5308;Shcherbanivska;Щербанівська;Щербаневская
UA5602001;UA5602;Antonivska;Антонівська;Антоновская
UA5602003;UA5602;Varaska;Вараська;Варашская
UA5602005;UA5602;Volodymyretska;Володимирецька;Владимирецкая
UA5602007;UA5602;Zarichnenska;Зарічненська;Заречненская
UA5602009;UA5602;Kanonytska;Каноницька;Каноничская
UA5602011;UA5602;Loknytska;Локницька;Локницкая
UA5602013;UA5602;Polytska;Полицька;Полицкая
UA5602015;UA5602;Rafalivska;Рафалівська;Рафаловская
UA5604001;UA5604;Bokiimivska;Бокіймівська;Бокиймовская
UA5604003;UA5604;Boremelska;Боремельська;Боремельская
UA5604005;UA5604;Varkovytska;Варковицька;Варковичская
UA5604007;UA5604;Verbska;Вербська;Вербская
UA5604009;UA5604;Demydivska;Демидівська;Демидовская
UA5604011;UA5604;Dubenska;Дубенська;Дубновская
UA5604013;UA5604;Kozynska;Козинська;Козинская
UA5604015;UA5604;Krupetska;Крупецька;Крупецкая
UA5604017;UA5604;Myrohoshchanska;Мирогощанська;Мирогощанская
UA5604019;UA5604;Mlynivska;Млинівська;Млиновская
UA5604021;UA5604;Ostrozhetska;Острожецька;Острожецкая
UA5604023;UA5604;Pidloztsivska;Підлозцівська;Подлозцовская
UA5604025;UA5604;Povchanska;Повчанська;Повчанская
UA5604027;UA5604;Pryvilnenska;Привільненська;Привольненская
UA5604029;UA5604;Radyvylivska;Радивилівська;Радивиловская
UA5604031;UA5604;Semydubska;Семидубська;Семидубовская
UA5604033;UA5604;Smyzka;Смизька;Смигская
UA5604035;UA5604;Tarakanivska;Тараканівська;Таракановская
UA5604037;UA5604;Yaroslavytska;Ярославицька;Ярославичская
UA5606001;UA5606;Babynska;Бабинська;Бабинская
UA5606003;UA5606;Bereznivska;Березнівська;Березновская
UA5606005;UA5606;Bilokrynytska;Білокриницька;Белокриницкая
UA5606007;UA5606;Buhrynska;Бугринська;Бугринская
UA5606009;UA5606;Velykomezhyritska;Великомежиріцька;Великомежиричская
UA5606011;UA5606;Velykoomelianska;Великоомелянська;Великоомелянская
UA5606013;UA5606;Holovynska;Головинська;Головинская
UA5606015;UA5606;Horodotska;Городоцька;Городокская
UA5606017;UA5606;Hoshchanska;Гощанська;Гощанская
UA5606019;UA5606;Derazhnenska;Деражненська;Деражненская
UA5606021;UA5606;Diadkovytska;Дядьковицька;Дядьковичская
UA5606023;UA5606;Zdovbytska;Здовбицька;Здолбицкая
UA5606025;UA5606;Zdolbunivska;Здолбунівська;Здолбуновская
UA5606027;UA5606;Zorianska;Зорянська;Зарянская
UA5606029;UA5606;Klevanska;Клеванська;Клеванская
UA5606031;UA5606;Koretska;Корецька;Корецкая
UA5606033;UA5606;Kornynska;Корнинська;Корнинская
UA5606035;UA5606;Kostopilska;Костопільська;Костопольская
UA5606037;UA5606;Malynska;Малинська;Малинская
UA5606039;UA5606;Maloliubashanska;Малолюбашанська;Малолюбашанская
UA5606041;UA5606;Mizotska;Мізоцька;Мизочская
UA5606043;UA5606;Oleksandriiska;Олександрійська;Александрийская
UA5606045;UA5606;Ostrozka;Острозька;Острожская
UA5606047;UA5606;Rivnenska;Рівненська;Ровенская
UA5606049;UA5606;Sosnivska;Соснівська;Сосновская
UA5606051;UA5606;Shpanivska;Шпанівська;Шпановская
UA5608001;UA5608;Berezivska;Березівська;Березовская
UA5608003;UA5608;Vyrivska;Вирівська;Вировская
UA5608005;UA5608;Vysotska;Висоцька;Высоцкая
UA5608007;UA5608;Dubrovytska;Дубровицька;Дубровицкая
UA5608009;UA5608;Klesivska;Клесівська;Клесовская
UA5608011;UA5608;Myliatska;Миляцька;Милячская
UA5608013;UA5608;Nemovytska;Немовицька;Немовичская
UA5608015;UA5608;Rokytnivska;Рокитнівська;Рокитновская
UA5608017;UA5608;Sarnenska;Сарненська;Сарненская
UA5608019;UA5608;Starosilska;Старосільська;Старосельская
UA5608021;UA5608;Stepanska;Степанська;Степанская
UA5902001;UA5902;Bochechkivska;Бочечківська;Бочечковская
UA5902003;UA5902;Burynska;Буринська;Бурынская
UA5902005;UA5902;Duboviazivska;Дубов'язівська;Дубовязовская
UA5902007;UA5902;Konotopska;Конотопська;Конотопская
UA5902009;UA5902;Krolevetska;Кролевецька;Кролевецкая
UA5902011;UA5902;Novoslobidska;Новослобідська;Новослободская
UA5902013;UA5902;Popivska;Попівська;Поповская
UA5902015;UA5902;Putyvlska;Путивльська;Путивльская
UA5904001;UA5904;Boromlianska;Боромлянська;Боромлянская
UA5904003;UA5904;Velykopysarivska;Великописарівська;Великописаревская
UA5904005;UA5904;Hrunska;Грунська;Груньская
UA5904007;UA5904;Kyrykivska;Кириківська;Кириковская
UA5904009;UA5904;Komyshanska;Комишанська;Камышанская
UA5904011;UA5904;Okhtyrska;Охтирська;Ахтырская
UA5904013;UA5904;Trostianetska;Тростянецька;Тростянецкая
UA5904015;UA5904;Chernechchynska;Чернеччинська;Чернетчинская
UA5904017;UA5904;Chupakhivska;Чупахівська;Чупаховская
UA5906001;UA5906;Andriiashivska;Андріяшівська;Андрияшевская
UA5906003;UA5906;Vilshanska;Вільшанська;Ольшанская
UA5906005;UA5906;Korovynska;Коровинська;Коровинская
UA5906007;UA5906;Lypovodolynska;Липоводолинська;Липоводолинская
UA5906009;UA5906;Nedryhailivska;Недригайлівська;Недригайловская
UA5906011;UA5906;Romenska;Роменська;Роменская
UA5906013;UA5906;Synivska;Синівська;Синевская
UA5906015;UA5906;Khmelivska;Хмелівська;Хмелевская
UA5908001;UA5908;Bezdrytska;Бездрицька;Бездрикская
UA5908003;UA5908;Bilopilska;Білопільська;Белопольская
UA5908005;UA5908;Verkhnosyrovatska;Верхньосироватська;Верхнесыроватская
UA5908007;UA5908;Vorozhbianska;Ворожбянська;Ворожбянская
UA5908009;UA5908;Krasnopilska;Краснопільська;Краснопольская
UA5908011;UA5908;Lebedynska;Лебединська;Лебединская
UA5908013;UA5908;Mykolaivska;Миколаївська;Николаевская
UA5908015;UA5908;Mykolaivska;Миколаївська;Николаевская
UA5908017;UA5908;Myropilska;Миропільська;Миропольская
UA5908019;UA5908;Nyzhnosyrovatska;Нижньосироватська;Нижнесыроватская
UA5908021;UA5908;Richkivska;Річківська;Речковская
UA5908023;UA5908;Sadivska;Садівська;Садовская
UA5908025;UA5908;Stepanivska;Степанівська;Степановская
UA5908027;UA5908;Sumska;Сумська;Сумская
UA5908029;UA5908;Khotinska;Хотінська;Хотенская
UA5908031;UA5908;Yunakivska;Юнаківська;Юнаковская
UA5910001;UA5910;Berezivska;Березівська;Березовская
UA5910003;UA5910;Hlukhivska;Глухівська;Глуховская
UA5910005;UA5910;Druzhbivska;Дружбівська;Дружбовская
UA5910007;UA5910;Esmanska;Есманьська;Эсманская
UA5910009;UA5910;Znob-Novhorodska;Зноб-Новгородська;Знобь-Новгородская
UA5910011;UA5910;Sveska;Свеська;Свесская
UA5910013;UA5910;Seredyno-Budska;Середино-Будська;Середино-Будская
UA5910015;UA5910;Shalyhynska;Шалигинська;Шалыгинская
UA5910017;UA5910;Shostkynska;Шосткинська;Шосткинская
UA5910019;UA5910;Yampilska;Ямпільська;Ямпольская
UA6102001;UA6102;Borsukivska;Борсуківська;Барсуковская
UA6102003;UA6102;Velykodederkalska;Великодедеркальська;Великодедеркальская
UA6102005;UA6102;Vyshnivetska;Вишнівецька;Вишневецкая
UA6102007;UA6102;Kremenetska;Кременецька;Кременецкая
UA6102009;UA6102;Lanovetska;Лановецька;Лановецкая
UA6102011;UA6102;Lopushnenska;Лопушненська;Лопушненская
UA6102013;UA6102;Pochaivska;Почаївська;Почаевская
UA6102015;UA6102;Shumska;Шумська;Шумская
UA6104001;UA6104;Baikovetska;Байковецька;Байковецкая
UA6104003;UA6104;Berezhanska;Бережанська;Бережанская
UA6104005;UA6104;Biletska;Білецька;Белецкая
UA6104007;UA6104;Velykoberezovytska;Великоберезовицька;Великоберезовицкая
UA6104009;UA6104;Velykobirkivska;Великобірківська;Великоборковская
UA6104011;UA6104;Velykohaivska;Великогаївська;Великогаевская
UA6104013;UA6104;Zalozetska;Залозецька;Залозецкая
UA6104015;UA6104;Zbarazka;Збаразька;Збаражская
UA6104017;UA6104;Zborivska;Зборівська;Зборовская
UA6104019;UA6104;Zolotnykivska;Золотниківська;Золотниковская
UA6104021;UA6104;Ivanivska;Іванівська;Ивановская
UA6104023;UA6104;Kozivska;Козівська;Козовская
UA6104025;UA6104;Kozlivska;Козлівська;Козловская
UA6104027;UA6104;Kupchynetska;Купчинецька;Купчинецкая
UA6104029;UA6104;Mykulynetska;Микулинецька;Микулинецкая
UA6104031;UA6104;Naraivska;Нараївська;Нараевская
UA6104033;UA6104;Ozernianska;Озернянська;Озернянская
UA6104035;UA6104;Pidvolochyska;Підволочиська;Подволочисская
UA6104037;UA6104;Pidhaietska;Підгаєцька;Подгаецкая
UA6104039;UA6104;Pidhorodnianska;Підгороднянська;Подгороднянская
UA6104041;UA6104;Saranchukivska;Саранчуківська;Саранчуковская
UA6104043;UA6104;Skalatska;Скалатська;Скалатская
UA6104045;UA6104;Skorykivska;Скориківська;Скориковская
UA6104047;UA6104;Terebovlianska;Теребовлянська;Теребовлянская
UA6104049;UA6104;Ternopilska;Тернопільська;Тернопольская
UA6106001;UA6106;Bilobozhnytska;Білобожницька;Белобожницкая
UA6106003;UA6106;Bilche-Zolotetska;Більче-Золотецька;Бильче-Золотецкая
UA6106005;UA6106;Borshchivska;Борщівська;Борщевская
UA6106007;UA6106;Buchatska;Бучацька;Бучачская
UA6106009;UA6106;Vasylkovetska;Васильковецька;Васильковецкая
UA6106011;UA6106;Hrymailivska;Гримайлівська;Гримайловская
UA6106013;UA6106;Husiatynska;Гусятинська;Гусятинская
UA6106015;UA6106;Zavodska;Заводська;Заводская
UA6106017;UA6106;Zalishchytska;Заліщицька;Залещицкая
UA6106019;UA6106;Zolotopotitska;Золотопотіцька;Золотопотокская
UA6106021;UA6106;Ivane-Pustenska;Іване-Пустенська;Иване-Пустенская
UA6106023;UA6106;Kolyndianska;Колиндянська;Колындянская
UA6106025;UA6106;Kopychynetska;Копичинецька;Копычинская
UA6106027;UA6106;Koropetska;Коропецька;Коропецкая
UA6106029;UA6106;Melnytse-Podilska;Мельнице-Подільська;Мельнице-Подольская
UA6106031;UA6106;Monastyryska;Монастириська;Монастырисская
UA6106033;UA6106;Nahirianska;Нагірянська;Нагорянская
UA6106035;UA6106;Skala-Podilska;Скала-Подільська;Скала-Подольская
UA6106037;UA6106;Tovstenska;Товстенська;Толстенская
UA6106039;UA6106;Trybukhivska;Трибухівська;Трибуховская
UA6106041;UA6106;Khorostkivska;Хоростківська;Хоростковская
UA6106043;UA6106;Chortkivska;Чортківська;Чортковская
UA6302001;UA6302;Bohodukhivska;Богодухівська;Богодуховская
UA6302003;UA6302;Valkivska;Валківська;Валковская
UA6302005;UA6302;Zolochivska;Золочівська;Золочевская
UA6302007;UA6302;Kolomatska;Коломацька;Коломакская
UA6302009;UA6302;Krasnokutska;Краснокутська;Краснокутская
UA6304001;UA6304;Balakliiska;Балаклійська;Балаклейская
UA6304003;UA6304;Barvinkivska;Барвінківська;Барвенковская
UA6304005;UA6304;Borivska;Борівська;Боровская
UA6304007;UA6304;Donetska;Донецька;Донецкая
UA6304009;UA6304;Iziumska;Ізюмська;Изюмская
UA6304011;UA6304;Kunievska;Куньєвська;Куньевская
UA6304013;UA6304;Oskilska;Оскільська;Оскольская
UA6304015;UA6304;Savynska;Савинська;Савинская
UA6306001;UA6306;Zachepylivska;Зачепилівська;Зачепиловская
UA6306003;UA6306;Kehychivska;Кегичівська;Кегичевская
UA6306005;UA6306;Krasnohradska;Красноградська;Красноградская
UA6306007;UA6306;Natalynska;Наталинська;Наталинская
UA6306009;UA6306;Sakhnovshchynska;Сахновщинська;Сахновщиниская
UA6306011;UA6306;Starovirivska;Старовірівська;Староверовская
UA6308001;UA6308;Velykoburlutska;Великобурлуцька;Великобурлукская
UA6308003;UA6308;Vilkhuvatska;Вільхуватська;Ольховатская
UA6308005;UA6308;Dvorichanska;Дворічанська;Двуречанская
UA6308007;UA6308;Kindrashivska;Кіндрашівська;Кондрашовская
UA6308009;UA6308;Kupianska;Куп'янська;Купянская
UA6308011;UA6308;Kurylivska;Курилівська;Куриловская
UA6308013;UA6308;Petropavlivska;Петропавлівська;Петропавловская
UA6308015;UA6308;Shevchenkivska;Шевченківська;Шевченковская
UA6310001;UA6310;Biliaivska;Біляївська;Беляевская
UA6310003;UA6310;Blyzniukivska;Близнюківська;Близнюковская
UA6310005;UA6310;Lozivska;Лозівська;Лозовская
UA6310007;UA6310;Oleksiivska;Олексіївська;Алексеевская
UA6310009;UA6310;Pervomaiska;Первомайська;Первомайская
UA6312001;UA6312;Bezliudivska;Безлюдівська;Безлюдовская
UA6312003;UA6312;Vysochanska;Височанська;Высочанская
UA6312005;UA6312;Vilkhivska;Вільхівська;Ольховская
UA6312007;UA6312;Derhachivska;Дергачівська;Дергачевская
UA6312009;UA6312;Lypetska;Липецька;Липецкая
UA6312011;UA6312;Liubotynska;Люботинська;Люботинская
UA6312013;UA6312;Malodanylivska;Малоданилівська;Молоданиловская
UA6312015;UA6312;Merefianska;Мереф'янська;Мерефянская
UA6312017;UA6312;Novovodolazka;Нововодолазька;Нововодолажская
UA6312019;UA6312;Pivdennomiska;Південноміська;Пивденская
UA6312021;UA6312;Pisochynska;Пісочинська;Песочинская
UA6312023;UA6312;Rohanska;Роганська;Роганская
UA6312025;UA6312;Solonytsivska;Солоницівська;Солоницевская
UA6312027;UA6312;Kharkivska;Харківська;Харьковская
UA6312029;UA6312;Tsyrkunivska;Циркунівська;Циркуновская
UA6314001;UA6314;Vovchanska;Вовчанська;Волчанская
UA6314003;UA6314;Zmiivska;Зміївська;Змиевская
UA6314005;UA6314;Malynivska;Малинівська;Малиновская
UA6314007;UA6314;Novopokrovska;Новопокровська;Новопокровская
UA6314009;UA6314;Pechenizka;Печенізька;Печенежская
UA6314011;UA6314;Slobozhanska;Слобожанська;Слобожанская
UA6314013;UA6314;Starosaltivska;Старосалтівська;Старосалтовская
UA6314015;UA6314;Chkalovska;Чкаловська;Чкаловская
UA6314017;UA6314;Chuhuivska;Чугуївська;Чугуевская
UA6502001;UA6502;Beryslavska;Бериславська;Бериславская
UA6502003;UA6502;Borozenska;Борозенська;Борозенская
UA6502005;UA6502;Velykooleksandrivska;Великоолександрівська;Великоалександровская
UA6502007;UA6502;Vysokopilska;Високопільська;Высокопольская
UA6502009;UA6502;Kalynivska;Калинівська;Калиновская
UA6502011;UA6502;Kochubeivska;Кочубеївська;Кочубеевская
UA6502013;UA6502;Mylivska;Милівська;Мыловская
UA6502015;UA6502;Novovorontsovska;Нововоронцовська;Нововоронцовская
UA6502017;UA6502;Novooleksandrivska;Новоолександрівська;Новоалександровская
UA6502019;UA6502;Novoraiska;Новорайська;Новорайская
UA6502021;UA6502;Tiahynska;Тягинська;Тягинская
UA6504001;UA6504;Henicheska;Генічеська;Геническая
UA6504003;UA6504;Ivanivska;Іванівська;Ивановская
UA6504005;UA6504;Nyzhnosirohozka;Нижньосірогозька;Нижнесерогозская
UA6504007;UA6504;Novotroitska;Новотроїцька;Новотроицкая
UA6506001;UA6506;Askaniia-Nova;Асканія-Нова;Аскания-Новая
UA6506003;UA6506;Velykolepetyska;Великолепетиська;Великолепетихская
UA6506005;UA6506;Verkhnorohachytska;Верхньорогачицька;Верхнерогачикская
UA6506007;UA6506;Hornostaivska;Горностаївська;Горностаевская
UA6506009;UA6506;Zelenopidska;Зеленопідська;Зеленоподская
UA6506011;UA6506;Kakhovska;Каховська;Каховская
UA6506013;UA6506;Kostiantynivska;Костянтинівська;Константиновская
UA6506015;UA6506;Liubymivska;Любимівська;Любимовская
UA6506017;UA6506;Novokakhovska;Новокаховська;Новокаховская
UA6506019;UA6506;Prysyvaska;Присиваська;Присивашская
UA6506021;UA6506;Rubanivska;Рубанівська;Рубановская
UA6506023;UA6506;Tavrychanska;Тавричанська;Тавричанская
UA6506025;UA6506;Tavriiska;Таврійська;Таврийская
UA6506027;UA6506;Khrestivska;Хрестівська;Крестовская
UA6506029;UA6506;Chaplynska;Чаплинська;Чаплинская
UA6508001;UA6508;Bekhterska;Бехтерська;Бехтерская
UA6508003;UA6508;Holoprystanska;Голопристанська;Голопристанская
UA6508005;UA6508;Dolmativska;Долматівська;Долматовская
UA6508007;UA6508;Kalanchatska;Каланчацька;Каланчакская
UA6508009;UA6508;Lazurnenska;Лазурненська;Лазурненская
UA6508011;UA6508;Myrnenska;Мирненська;Мирненская
UA6508013;UA6508;Novomykolaivska;Новомиколаївська;Новониколаевская
UA6508015;UA6508;Skadovska;Скадовська;Скадовская
UA6508017;UA6508;Chulakivska;Чулаківська;Чулаковская
UA6510001;UA6510;Bilozerska;Білозерська;Белозерская
UA6510003;UA6510;Velykokopanivska;Великокопанівська;Великокопановская
UA6510005;UA6510;Vynohradivska;Виноградівська;Виноградовская
UA6510007;UA6510;Darivska;Дар'ївська;Дарьевская
UA6510009;UA6510;Muzykivska;Музиківська;Музыковская
UA6510011;UA6510;Oleshkivska;Олешківська;Алешковская
UA6510013;UA6510;Stanislavska;Станіславська;Станиславская
UA6510015;UA6510;Khersonska;Херсонська;Херсонская
UA6510017;UA6510;Chornobaivska;Чорнобаївська;Чернобаевская
UA6510019;UA6510;Yuvileina;Ювілейна;Юбилейная
UA6802001;UA6802;Hukivska;Гуківська;Гуковская
UA6802003;UA6802;Humenetska;Гуменецька;Гуменецкая
UA6802005;UA6802;Dunaievetska;Дунаєвецька;Дунаевецкая
UA6802007;UA6802;Zhvanetska;Жванецька;Жванецкая
UA6802009;UA6802;Zakupnenska;Закупненська;Закупненская
UA6802011;UA6802;Kamianets-Podilska;Кам'янець-Подільська;Каменец-Подольская
UA6802013;UA6802;Kytaihorodska;Китайгородська;Китайгородская
UA6802015;UA6802;Makivska;Маківська;Маковская
UA6802017;UA6802;Novounaievetska;Новодунаєвецька;Новодунаевецкая
UA6802019;UA6802;Novoushytska;Новоушицька;Новоушицкая
UA6802021;UA6802;Orynynska;Орининська;Орининская
UA6802023;UA6802;Slobidsko-Kulchiievetska;Слобідсько-Кульчієвецька;Слободско-Кульчиевецкая
UA6802025;UA6802;Smotrytska;Смотрицька;Смотричская
UA6802027;UA6802;Staroushytska;Староушицька;Староушицкая
UA6802029;UA6802;Chemerovetska;Чемеровецька;Чемеровецкая
UA6804001;UA6804;Antoninska;Антонінська;Антонинская
UA6804003;UA6804;Viitovetska;Війтовецька;Войтовецкая
UA6804005;UA6804;Vinkovetska;Віньковецька;Виньковецкая
UA6804007;UA6804;Vovkovynetska;Вовковинецька;Волковинецкая
UA6804009;UA6804;Volochyska;Волочиська;Волочисская
UA6804011;UA6804;Hvardiiska;Гвардійська;Гвардейская
UA6804013;UA6804;Horodotska;Городоцька;Городокская
UA6804015;UA6804;Derazhnianska;Деражнянська;Деражнянская
UA6804017;UA6804;Zasluchnenska;Заслучненська;Заслучненская
UA6804019;UA6804;Zinkivska;Зіньківська;Зиньковская
UA6804021;UA6804;Krasylivska;Красилівська;Красиловская
UA6804023;UA6804;Letychivska;Летичівська;Летичевская
UA6804025;UA6804;Lisovohrynivetska;Лісовогринівецька;Лесовогриневецкая
UA6804027;UA6804;Medzhybizka;Меджибізька;Меджибожская
UA6804029;UA6804;Myroliubnenska;Миролюбненська;Миролюбненская
UA6804031;UA6804;Narkevytska;Наркевицька;Наркевичская
UA6804033;UA6804;Rozsoshanska;Розсошанська;Россошанская
UA6804035;UA6804;Satanivska;Сатанівська;Сатановская
UA6804037;UA6804;Solobkovetska;Солобковецька;Солобковецкая
UA6804039;UA6804;Starokostiantynivska;Старокостянтинівська;Староконстантиновская
UA6804041;UA6804;Staroostropilska;Староостропільська;Староостропольская
UA6804043;UA6804;Starosyniavska;Старосинявська;Старосинявская
UA6804045;UA6804;Teofipolska;Теофіпольська;Теофипольская
UA6804047;UA6804;Khmelnytska;Хмельницька;Хмельницкая
UA6804049;UA6804;Chornoostrivska;Чорноострівська;Черноостровская
UA6804051;UA6804;Shchyborivska;Щиборівська;Щиборовская
UA6804053;UA6804;Yarmolynetska;Ярмолинецька;Ярмолинецкая
UA6806001;UA6806;Berezdivska;Берездівська;Берездовская
UA6806003;UA6806;Bilohirska;Білогірська;Белогорская
UA6806005;UA6806;Hannopilska;Ганнопільська;Аннопольская
UA6806007;UA6806;Hrytsivska;Грицівська;Грицевская
UA6806009;UA6806;Iziaslavska;Ізяславська;Изяславская
UA6806011;UA6806;Krupetska;Крупецька;Крупецкая
UA6806013;UA6806;Lenkovetska;Ленковецька;Ленковецкая
UA6806015;UA6806;Mykhailiutska;Михайлюцька;Михайлючская
UA6806017;UA6806;Netishynska;Нетішинська;Нетешинская
UA6806019;UA6806;Pluzhnenska;Плужненська;Плужненская
UA6806021;UA6806;Polonska;Полонська;Полонская
UA6806023;UA6806;Poninkivska;Понінківська;Понинковская
UA6806025;UA6806;Sakhnovetska;Сахновецька;Сахновецкая
UA6806027;UA6806;Slavutska;Славутська;Славутская
UA6806029;UA6806;Sudylkivska;Судилківська;Судилковская
UA6806031;UA6806;Ulashanivska;Улашанівська;Улашановская
UA6806033;UA6806;Shepetivska;Шепетівська;Шепетовская
UA6806035;UA6806;Yampilska;Ямпільська;Ямпольская
UA7102001;UA7102;Buzhanska;Бужанська;Бужанская
UA7102003;UA7102;Vatutinska;Ватутінська;Ватутинская
UA7102005;UA7102;Vynohradska;Виноградська;Виноградская
UA7102007;UA7102;Vilshanska;Вільшанська;Ольшанская
UA7102009;UA7102;Vodianytska;Водяницька;Водяникская
UA7102011;UA7102;Yerkivska;Єрківська;Ерковская
UA7102013;UA7102;Zvenyhorodska;Звенигородська;Звенигородская
UA7102015;UA7102;Katerynopilska;Катеринопільська;Катеринопольская
UA7102017;UA7102;Lypianska;Лип'янська;Липянская
UA7102019;UA7102;Lysianska;Лисянська;Лысянская
UA7102021;UA7102;Matusivska;Матусівська;Матусовская
UA7102023;UA7102;Mokrokalyhirska;Мокрокалигірська;Мокрокалигорская
UA7102025;UA7102;Selyshchenska;Селищенська;Селищенская
UA7102027;UA7102;Steblivska;Стеблівська;Стеблевская
UA7102029;UA7102;Talnivska;Тальнівська;Тальновская
UA7102031;UA7102;Shevchenkivska;Шевченківська;Шевченковская
UA7102033;UA7102;Shpolianska;Шполянська;Шполянская
UA7104001;UA7104;Velykokhutirska;Великохутірська;Великохуторская
UA7104003;UA7104;Voznesenska;Вознесенська;Вознесенская
UA7104005;UA7104;Helmiazivska;Гельмязівська;Гельмязовская
UA7104007;UA7104;Drabivska;Драбівська;Драбовская
UA7104009;UA7104;Zolotoniska;Золотоніська;Золотоношская
UA7104011;UA7104;Zorivska;Зорівська;Зоревская
UA7104013;UA7104;Irkliivska;Іркліївська;Ирклиевская
UA7104015;UA7104;Novodmytrivska;Новодмитрівська;Новодмитровская
UA7104017;UA7104;Pishchanska;Піщанська;Песчанская
UA7104019;UA7104;Chornobaivska;Чорнобаївська;Чернобаевская
UA7104021;UA7104;Shramkivska;Шрамківська;Шрамковская
UA7106001;UA7106;Babanska;Бабанська;Бабанская
UA7106003;UA7106;Bashtechkivska;Баштечківська;Баштечковская
UA7106005;UA7106;Butska;Буцька;Букская
UA7106007;UA7106;Dmytrushkivska;Дмитрушківська;Дмитрушковская
UA7106009;UA7106;Zhashkivska;Жашківська;Жашковская
UA7106011;UA7106;Ivankivska;Іваньківська;Иваньковская
UA7106013;UA7106;Ladyzhynska;Ладижинська;Ладыжинская
UA7106015;UA7106;Mankivska;Маньківська;Маньковская
UA7106017;UA7106;Monastyryshchenska;Монастирищенська;Монастырищенская
UA7106019;UA7106;Palanska;Паланська;Паланская
UA7106021;UA7106;Umanska;Уманська;Уманская
UA7106023;UA7106;Khrystynivska;Христинівська;Христиновская
UA7108001;UA7108;Balakleivska;Балаклеївська;Балаклеевская
UA7108003;UA7108;Berezniakivska;Березняківська;Березняковская
UA7108005;UA7108;Bilozirska;Білозірська;Белозорская
UA7108007;UA7108;Bobrytska;Бобрицька;Бобрицкая
UA7108009;UA7108;Budyshchenska;Будищенська;Будищенская
UA7108011;UA7108;Horodyshchenska;Городищенська;Городищенская
UA7108013;UA7108;Kamianska;Кам'янська;Каменская
UA7108015;UA7108;Kanivska;Канівська;Каневская
UA7108017;UA7108;Korsun-Shevchenkivska;Корсунь-Шевченківська;Корсунь-Шевченковская
UA7108019;UA7108;Leskivska;Леськівська;Леськовская
UA7108021;UA7108;Lipliavska;Ліплявська;Леплявская
UA7108023;UA7108;Medvedivska;Медведівська;Медведевская
UA7108025;UA7108;Mykhailivska;Михайлівська;Михайловская
UA7108027;UA7108;Mliivska;Мліївська;Млиевская
UA7108029;UA7108;Moshnivska;Мошнівська;Мошновская
UA7108031;UA7108;Nabutivska;Набутівська;Набутовская
UA7108033;UA7108;Rotmistrivska;Ротмістрівська;Ротмистровская
UA7108035;UA7108;Ruskopolianska;Руськополянська;Русскополянская
UA7108037;UA7108;Sahunivska;Сагунівська;Сагуновская
UA7108039;UA7108;Smilianska;Смілянська;Смелянская
UA7108041;UA7108;Stepanetska;Степанецька;Степанецкая
UA7108043;UA7108;Stepankivska;Степанківська;Степанковская
UA7108045;UA7108;Ternivska;Тернівська;Терновская
UA7108047;UA7108;Chervonoslobidska;Червонослобідська;Червонослободская
UA7108049;UA7108;Cherkaska;Черкаська;Черкасская
UA7108051;UA7108;Chyhyrynska;Чигиринська;Чигиринская
UA7302001;UA7302;Banylivska;Банилівська;Баниловская
UA7302003;UA7302;Berehometska;Берегометська;Берегометская
UA7302005;UA7302;Brusnytska;Брусницька;Брусницкая
UA7302007;UA7302;Vashkivetska;Вашківецька;Вашковецкая
UA7302009;UA7302;Vyzhnytska;Вижницька;Вижницкая
UA7302011;UA7302;Koniatynska;Конятинська;Конятинская
UA7302013;UA7302;Putylska;Путильська;Путильская
UA7302015;UA7302;Seliatynska;Селятинська;Селятинская
UA7302017;UA7302;Ust-Putylska;Усть-Путильська;Усть-Путильская
UA7304001;UA7304;Vashkovetska;Вашковецька;Вашковецкая
UA7304003;UA7304;Kelmenetska;Кельменецька;Кельменецкая
UA7304005;UA7304;Klishkovetska;Клішковецька;Клишковецкая
UA7304007;UA7304;Livynetska;Лівинецька;Левинецкая
UA7304009;UA7304;Mamalyhivska;Мамалигівська;Мамалыговская
UA7304011;UA7304;Nedoboivska;Недобоївська;Недобоевская
UA7304013;UA7304;Novodnistrovska;Новодністровська;Новоднестровская
UA7304015;UA7304;Rukshynska;Рукшинська;Рукшинская
UA7304017;UA7304;Sokyrianska;Сокирянська;Сокирянская
UA7304019;UA7304;Khotynska;Хотинська;Хотинская
UA7306001;UA7306;Boianska;Боянська;Боянская
UA7306003;UA7306;Vanchykovetska;Ванчиковецька;Ванчиковецкая
UA7306005;UA7306;Velykokuchurivska;Великокучурівська;Великокучуровская
UA7306007;UA7306;Verenchanska;Веренчанська;Веренчанская
UA7306009;UA7306;Viknianska;Вікнянська;Окнянская
UA7306011;UA7306;Volokivska;Волоківська;Волоковская
UA7306013;UA7306;Hertsaivska;Герцаївська;Герцаевская
UA7306015;UA7306;Hlybotska;Глибоцька;Глыбокская
UA7306017;UA7306;Horishnosherovetska;Горішньошеровецька;Горишнешеровецкая
UA7306019;UA7306;Zastavnivska;Заставнівська;Заставновская
UA7306021;UA7306;Kadubovetska;Кадубовецька;Кадубовецкая
UA7306023;UA7306;Kamianetska;Кам'янецька;Каменская
UA7306025;UA7306;Kamianska;Кам'янська;Каменская
UA7306027;UA7306;Karapchivska;Карапчівська;Карапчовская
UA7306029;UA7306;Kitsmanska;Кіцманська;Кицманская
UA7306031;UA7306;Kostryzhivska;Кострижівська;Кострижевская
UA7306033;UA7306;Krasnoilska;Красноїльська;Красноильская
UA7306035;UA7306;Mahalska;Магальська;Магальская
UA7306037;UA7306;Mamaivska;Мамаївська;Мамаевская
UA7306039;UA7306;Nepolokovetska;Неполоковецька;Неполоковецкая
UA7306041;UA7306;Novoselytska;Новоселицька;Новоселицкая
UA7306043;UA7306;Ostrytska;Острицька;Острицкая
UA7306045;UA7306;Petrovetska;Петровецька;Петровецкая
UA7306047;UA7306;Stavchanska;Ставчанська;Ставчанская
UA7306049;UA7306;Storozhynetska;Сторожинецька;Сторожинецкая
UA7306051;UA7306;Suchevenska;Сучевенська;Сучевенская
UA7306053;UA7306;Tarashanska;Тарашанська;Тарашанская
UA7306055;UA7306;Tereblechenska;Тереблеченська;Тереблеченская
UA7306057;UA7306;Toporivska;Топорівська;Топоровская
UA7306059;UA7306;Chahorska;Чагорська;Чагорская
UA7306061;UA7306;Chernivetska;Чернівецька;Черновицкая
UA7306063;UA7306;Chudeiska;Чудейська;Чудейская
UA7306065;UA7306;Yurkovetska;Юрковецька;Юрковецкая
UA7402001;UA7402;Koriukivska;Корюківська;Корюковская
UA7402003;UA7402;Menska;Менська;Менская
UA7402005;UA7402;Snovska;Сновська;Сновская
UA7402007;UA7402;Sosnytska;Сосницька;Сосницкая
UA7402009;UA7402;Kholmynska;Холминська;Холмынская
UA7404001;UA7404;Baturynska;Батуринська;Батуринская
UA7404003;UA7404;Bakhmatska;Бахмацька;Бахмачская
UA7404005;UA7404;Bobrovytska;Бобровицька;Бобровицкая
UA7404007;UA7404;Borznianska;Борзнянська;Борзнянская
UA7404009;UA7404;Vertiivska;Вертіївська;Вертиевская
UA7404011;UA7404;Vysochanska;Височанська;Высочанская
UA7404013;UA7404;Dmytrivska;Дмитрівська;Дмитровская
UA7404015;UA7404;Komarivska;Комарівська;Комаровская
UA7404017;UA7404;Krutivska;Крутівська;Крутовская
UA7404019;UA7404;Losynivska;Лосинівська;Лосиновcкая
UA7404021;UA7404;Makiivska;Макіївська;Макеевская
UA7404023;UA7404;Mrynska;Мринська;Мринская
UA7404025;UA7404;Nizhynska;Ніжинська;Нежинская
UA7404027;UA7404;Novobasanska;Новобасанська;Новобасанская
UA7404029;UA7404;Nosivska;Носівська;Носовская
UA7404031;UA7404;Plyskivska;Плисківська;Плисковская
UA7404033;UA7404;Talalaivska;Талалаївська;Талалаевская
UA7406001;UA7406;Koropska;Коропська;Коропская
UA7406003;UA7406;Novhorod-Siverska;Новгород-Сіверська;Новгород-Северская
UA7406005;UA7406;Ponornytska;Понорницька;Понорницкая
UA7406007;UA7406;Semenivska;Семенівська;Семеновская
UA7408001;UA7408;Varvynska;Варвинська;Варвинская
UA7408003;UA7408;Ichnianska;Ічнянська;Ичнянская
UA7408005;UA7408;Ladanska;Ладанська;Ладанская
UA7408007;UA7408;Lynovytska;Линовицька;Линовицкая
UA7408009;UA7408;Malodivytska;Малодівицька;Малодевицкая
UA7408011;UA7408;Parafiivska;Парафіївська;Парафиевская
UA7408013;UA7408;Prylutska;Прилуцька;Прилукская
UA7408015;UA7408;Sribnianska;Срібнянська;Сребнянская
UA7408017;UA7408;Sukhopolovianska;Сухополов'янська;Сухополовянская
UA7408019;UA7408;Talalaivska;Талалаївська;Талалаевская
UA7408021;UA7408;Yablunivska;Яблунівська;Яблоновская
UA7410001;UA7410;Bereznianska;Березнянська;Березнянская
UA7410003;UA7410;Honcharivska;Гончарівська;Гончаровская
UA7410005;UA7410;Horodnianska;Городнянська;Городнянская
UA7410007;UA7410;Desnianska;Деснянська;Деснянская
UA7410009;UA7410;Dobrianska;Добрянська;Добрянская
UA7410011;UA7410;Ivanivska;Іванівська;Ивановская
UA7410013;UA7410;Kyinska;Киїнська;Киенская
UA7410015;UA7410;Kyselivska;Киселівська;Киселевская
UA7410017;UA7410;Kiptivska;Кіптівська;Коптевская
UA7410019;UA7410;Kozeletska;Козелецька;Козелецкая
UA7410021;UA7410;Kulykivska;Куликівська;Куликовская
UA7410023;UA7410;Liubetska;Любецька;Любечская
UA7410025;UA7410;Mykhailo-Kotsiubynska;Михайло-Коцюбинська;Михайло-Коцюбинская
UA7410027;UA7410;Novobilouska;Новобілоуська;Новобелоусская
UA7410029;UA7410;Olyshivska;Олишівська;Олишевская
UA7410031;UA7410;Osterska;Остерська;Остерская
UA7410033;UA7410;Ripkynska;Ріпкинська;Репкинская
UA7410035;UA7410;Sednivska;Седнівська;Седневская
UA7410037;UA7410;Tupychivska;Тупичівська;Тупичевская
UA7410039;UA7410;Chernihivska;Чернігівська;Черниговская
UA8000000;UA8000;Kyivska;Київська;Киевский
UA8500000;UA8500;Sevastopilska;Севастопільська;Севастопольский"""


@click.command()  # noqa: C901
def upgrade(**kwargs):
    optionsets = [
        {
            "name": "ua_admin1",
            "data": ADMIN1.replace("\n", "\r\n"),
            "separator": ";",
            "columns": "pk,__,label",
        },
        {
            "name": "ua_admin2",
            "data": ADMIN2.replace("\n", "\r\n"),
            "separator": ";",
            "columns": "pk,parent,label",
        },
        {
            "name": "ua_admin3",
            "data": ADMIN3.replace("\n", "\r\n"),
            "separator": ";",
            "columns": "pk,parent,label",
        },
    ]
    for fld in optionsets:
        name = fld.pop("name")
        with atomic():
            OptionSet.objects.update_or_create(name=name, defaults=fld)

    custom_fields = [
        {
            "name": "MaritalStatus",
            "base_type": registry.forms.ChoiceField,
            "attrs": {"choices": ["Single", "Married", "Divorced", "Widowed", "Separated"]},
        },
        {
            "name": "ResidenceStatus",
            "base_type": registry.forms.ChoiceField,
            "attrs": {
                "choices": (
                    ("idp", "Displaced | Internally Displaced Person (IDP)"),
                    ("refugee", "Displaced | Refugee / Asylum Seeker"),
                    ("others_of_concern", "Displaced | Others of Concern"),
                    ("host", "Non-displaced | Hosting a displaced family"),
                    ("non_host", "Non-displaced | Not hosting a displaced family"),
                    ("returnee", "Returnee"),
                    ("repatriated", "Repatriate"),
                )
            },
        },
        {
            "name": "Gender",
            "base_type": registry.forms.ChoiceField,
            "attrs": {"choices": ["Female", "Male"]},
        },
        {
            "name": "ID Type",
            "base_type": registry.forms.ChoiceField,
            "attrs": {
                "choices": (
                    ("not_available", "Not Available"),
                    ("birth_certificate", "Birth Certificate"),
                    ("drivers_license", "Driver's License"),
                    ("electoral_card", "Electoral Card"),
                    ("unhcr_id", "UNHCR ID"),
                    ("national_id", "National ID"),
                    ("national_passport", "National Passport"),
                    ("scope_id", "WFP Scope ID"),
                    ("other", "Other"),
                )
            },
        },
        {
            "name": "Relationship",
            "base_type": registry.forms.ChoiceField,
            "attrs": {
                "choices": (
                    ("son_daughter", "Son / Daughter"),
                    ("wife_husband", "Wife / Husband"),
                    ("brother_sister", "Brother / Sister"),
                    ("mother_father", "Mother / Father"),
                    ("aunt_uncle", "Aunt / Uncle"),
                    ("grandmother_grandfather", "Grandmother / Grandfather"),
                    ("motherInLaw_fatherInLaw", "Mother-in-law / Father-in-law"),
                    ("daughterInLaw_sonInLaw", "Daughter-in-law / Son-in-law"),
                    ("sisterInLaw_brotherInLaw", "Sister-in-law / Brother-in-law"),
                    ("granddaugher_grandson", "Granddaughter / Grandson"),
                    ("nephew_niece", "Nephew / Niece"),
                    ("cousin", "Cousin"),
                )
            },
        },
        {
            "name": "Collector",
            "base_type": registry.forms.ChoiceField,
            "attrs": {
                "choices": (
                    ("primary", "Primary"),
                    ("alternate", "Alternate"),
                    ("no_role", "No"),
                )
            },
        },
        {
            "name": "Registration Method",
            "base_type": registry.forms.ChoiceField,
            "attrs": {
                "choices": (
                    ("hh_registration", "Household Registration"),
                    ("community", "Community-level Registration"),
                )
            },
        },
        {
            "name": "Data Sharing",
            "base_type": registry.fields.multi_checkbox.MultiCheckboxField,
            "attrs": {
                "choices": (
                    ("unicef", "UNICEF"),
                    ("humanitarian_partner", "Humanitarian partners"),
                    ("private_partner", "Private partners"),
                    ("government_partner", "Government partners"),
                )
            },
        },
    ]

    for fld in custom_fields:
        name = fld.pop("name")
        with atomic():
            custom_fld = CustomFieldType.build(name, fld)
            field_registry.register(custom_fld.get_class())

    base, __ = FlexForm.objects.get_or_create(name="Basic")
    hh, __ = FlexForm.objects.get_or_create(name="Household")
    ind, __ = FlexForm.objects.get_or_create(name="Individual")
    FlexForm.objects.get_or_create(name="Document")
    FlexForm.objects.get_or_create(name="Bank Account")

    base.add_formset(hh, extra=1, dynamic=False, max_num=1, min_num=1)
    base.add_formset(ind, extra=1, dynamic=True, min_num=1)

    base.add_field(
        "With whom may we share your information (select one or multiple among the following)?",
        registry.fields.MultiCheckboxField,
        choices=(
            ("unicef", "UNICEF"),
            ("priv_partner", "Private partners"),
            ("gov_partner", "Government partners"),
        ),
        name="enum_org",
    )
    base.add_field("Residence status", "aurora.core.models.ResidenceStatus")
    Registration.objects.get_or_create(name="Ucraina", defaults={"intro": INTRO, "flex_form": base})

    hh.add_field("Admin 1", registry.fields.AjaxSelectField, datasource="ua_admin1")
    hh.add_field(
        "Admin 2",
        registry.fields.AjaxSelectField,
        datasource="ua_admin2",
        parent="ua_admin1",
    )
    hh.add_field(
        "Admin 3",
        registry.fields.AjaxSelectField,
        datasource="ua_admin3",
        parent="ua_admin2",
    )
    ind.add_field("First Name")
    ind.add_field("Last Name")
